import QtQuick 1.1
import QtWebKit 1.0
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/HelpMapper.js" as HelpMapper

ActivationBasePage
{
	id: pagePurchasing
	objectName: "activationPagePurchasing"	

	// ActivationBasePage properties
	backButtonVisible:		false
	nextButtonVisible:		false
	cancelButtonVisible:	false
	wholePageArea:			true;

	property bool failed: false
		
	function trace(what)
	{
		console.log(what)
		context.ActivationPagePurchasing.Log(what)
	}

	function getHelpId()
	{
		return HelpMapper.ActivationPagePurchasingHelpId;
	}
	
	Widgets.BrowserPage
	{
		id: browser
		Component.onCompleted:	context.ActivationPagePurchasing.SetAccessManager(Network);
		url:					context.ActivationPagePurchasing.StartUrl;
		secured: true
		anchors.fill:			parent;

		onUrlLoadCompleted:
		{
			pagePurchasing.trace("IPP Loaded");

			if (!pagePurchasing.failed && context.ActivationPagePurchasing.IsSecurityError)
			{
				pagePurchasing.failed = true;
				showHtml(context.ActivationPagePurchasing.GetErrorHtmlUrl());
			}
		}

		onUrlLoadFailed:
		{
			pagePurchasing.trace("IPP Load failed");
			pagePurchasing.failed = true;
			showHtml(context.ActivationPagePurchasing.GetErrorHtmlUrl());
		}	
			
		js: QtObject
		{
			WebView.windowObjectName: "IppHandler"

			function trace(what)
			{
				pagePurchasing.trace(what)
			}

			function refresh()
			{
				context.ActivationPagePurchasing.IsSecurityError = false;
				pagePurchasing.failed = false;
				browser.url = context.ActivationPagePurchasing.StartUrl;
			}

			function closeWindow()
			{
				activationWizard.cancel();
			}

			function openUrl(url)
			{
				Window.OpenURL(url);
			}
				
			function openStartUrl()
			{
				Window.OpenURL(context.ActivationPagePurchasing.StartUrl);
			}

			function showHelp(topicId)
			{
				Help.Show(topicId);
			}

			function activateProduct(activationCode)
			{
				context.ActivationCode = activationCode;
				activationWizard.next("ActivationPage_InProductPurchasing");
			}

			function getApplicationId()
			{
				return context.ActivationPagePurchasing.ProductData.application_id;
			}

			function getApplicationLocalization()
			{
				pagePurchasing.trace("appLoc=" + context.ActivationPagePurchasing.ProductData.language);
				return context.ActivationPagePurchasing.ProductData.language;
			}
				
			function getApplicationRebrandingCode()
			{
				return context.ActivationPagePurchasing.ProductData.rebranding_code;
			}

			function getApplicationVersion()
			{
				var ver  = context.ActivationPagePurchasing.ProductData.application_version;
				var list  = ver.split(".");
				var json = {
					"Compilation" : list.pop(),
					"Build"	:		list.pop(),
					"Minor" :		list.pop(),
					"Major" :		list.pop()
							};
				return json;
			}

			function getSupportedApplicationIdList()
			{
				return context.ActivationPagePurchasing.ProductData.supported_app_ids;
			}

			function setMyAccountLogin(login)
			{
				context.ActivationPagePurchasing.MyAccountLogin = login;
			}

			function getMyAccountLogin()
			{
				return context.ActivationPagePurchasing.MyAccountLogin;
			}

			function openProxySettings()
			{
				context.ActivationPagePurchasing.ShowProxySettings();
			}
		}
	}
}
