import QtQuick 1.1
import QtWebKit 1.0
import QtWidgetProxies 1.0
import "../fonts" as Fonts

Item
{
	id: browserWindow

	property bool isDownloading: false	
	property variant	offlinePage;
	property bool secured: false

	Localizer { id:tr; scope:"Common" }
	property variant commonFontStyles: Fonts.Common{}

	property alias	browser:	content;
	property alias	js:			content.javaScriptWindowObjects;
	property alias	url:		content.url
	property alias	html:		content.html

	signal urlLoadStarted;
	signal urlLoadCompleted;
	signal urlLoadFailed;

	function showHtml(html)
	{
		content.url = html;
	}
		
	Flickable
	{
    	id: flickable
		contentWidth:	Math.max(width,content.width)
		contentHeight:	Math.max(height,content.height)    
		anchors.fill:	parent;
		interactive:	false		

		WebView
		{		
			id:											content
			visible:									!browserWindow.isDownloading
			objectName:									"WebView"
			settings.autoLoadImages:					true
			settings.javascriptEnabled:					true
			settings.linksIncludedInFocusChain:			true
			settings.javascriptCanAccessClipboard:		true
			settings.javascriptCanOpenWindows:			false
			settings.localContentCanAccessRemoteUrls:	true
			settings.pluginsEnabled:					true
			settings.allowDisplayOfInsecureContent:		!browserWindow.secured
			settings.allowRunningOfInsecureContent:		!browserWindow.secured
			pressGrabTime:								0
			preferredHeight:						browserWindow.height - 2
			preferredWidth:							browserWindow.width
			anchors.fill:							browserWindow
            y: 1

			onLoadFailed:
			{
				browserWindow.isDownloading = false;
				urlLoadFailed();
			}

			onLoadFinished:
			{
				browserWindow.isDownloading =  false;
				urlLoadCompleted();
			}

			onLoadStarted:
			{
				browserWindow.isDownloading = true;
				urlLoadStarted();
			}
		}
	}
	
    ScrollBar
	{
		id:scrollbar
		target:flickable
		anchors.top:flickable.top;
		anchors.right:parent.right;
		anchors.bottom: flickable.bottom;
	}

	Rectangle
	{
		objectName:		"hourGlasses"
		anchors.fill:	parent;
		visible:		browserWindow.isDownloading

		Column
		{
			anchors.verticalCenter:			parent.verticalCenter
			anchors.horizontalCenter:		parent.horizontalCenter
			spacing:                                          20;

			AnimatedImage
			{
				anchors.horizontalCenter:      parent.horizontalCenter
				source:                                    "../images/loader_48.gif"
			}

			Text
			{
				anchors.horizontalCenter:      parent.horizontalCenter
				text:                                         tr.Localize("BrowserWaitingMessage");
				font:                                         commonFontStyles.standardCommonTextFont
			}
		}
	}
}
