import QtQuick 1.1
import "../fonts" as Fonts
import "../Common.js" as Common
import "../Stat.js" as Stat

FocusScope
{
    id:comboButton
    objectName: "comboButton"
	property variant standartFontStyles: Fonts.Common{}

	property int tabOrder: 1

    property variant actionList
    property int defaultAction: 0

    property Item style: GrayStyle {}

    property bool showMenuAtArrow: true
    property int maxWidth
    property int minWidth
    property bool isInner
    height: childrenRect.height
    width: childrenRect.width
    signal pressed(int index)
    property string leftComboNormalImage: style.leftComboNormalImage
    property string leftComboHoverImage: style.leftComboHoverImage
    property string leftComboPressedImage: style.leftComboPressedImage
    property string rightComboNormalImage: style.rightComboNormalImage
    property string rightComboHoverImage: style.rightComboHoverImage
    property string rightComboPressedImage: style.rigthComboPressedImage
    property int horizontalMargin: 2
    property int buttonHeight: 30
    property int buttonRightWidth: 30
    
    property variant localizer
	property alias setAsDefaultButton: textButton.setAsDefaultButton

    // internal use only!
    property variant menu
    property string defaultText
	property bool isDefaultEnabled: actionList && defaultAction < actionList.length && actionList[defaultAction].action.IsEnabled
    onActiveFocusChanged: if (!activeFocus) textButton.focus = true;
	
    onActionListChanged: initMainButton();
    function initMainButton()
    {
		if(defaultAction < actionList.length)
		{
			var tempElement = actionList[defaultAction];
            defaultText = localizer == undefined ? tempElement.name : localizer.Localize(tempElement.name);
		}
    }

	function doOnMenuItemPressed(elementIndex, elementName)
	{
		var path = Common.buildDelegatelessPath(comboButton)  + ".popupMenu." + elementName;
        Stat.onButtonClick(path);
		comboButton.pressed(elementIndex);
	}

    function populateMenu()
    {
        if(comboButton.menu != undefined)
            comboButton.menu.destroy();
        if(actionList == undefined)
            return;

        var menuText = 'import QtWidgetProxies 1.0; PopupMenu{';
        menuText += ' styleSheet: "border-width:1px; border-style: solid; border-color: rgb(170, 170, 170);';
        menuText += ' background-color: rgb(255, 255, 255);selection-background-color: rgb(26, 152, 133); font:10pt FranklinGothicMediCondTT;";'
        menuText += ' items: ['
        var elementIndex = 0;
        while(elementIndex < actionList.length)
        {
            if (elementIndex != defaultAction)
            {
	            if((elementIndex > 0 && defaultAction != 0) || (elementIndex > 1))
	                menuText +=',';
				var tempElement = actionList[elementIndex];
	            menuText += 'PopupMenuAction{text : "';
	            menuText += localizer == undefined ? tempElement.name : localizer.Localize(tempElement.name);
	            menuText += '";enabled : ';
	            menuText += tempElement.action.IsEnabled;
	            menuText += '; onTriggered:comboButton.doOnMenuItemPressed(';
	            menuText += elementIndex;
				menuText += ", \"";
				menuText += localizer == undefined ? "popupMenuItem" + elementIndex : tempElement.name;
	            menuText += '\") }';
	        }
            ++elementIndex;
        }
        menuText += ']}';
        menu = Qt.createQmlObject(menuText, comboButton, "dynamicMenu");

        initMainButton();
    }
    
    function getNearRect(button)
    {
        return Qt.rect(button.x, button.y, button.width, button.height)
    }

    Button
    {
        id: textButton
		function makeObjectName()
		{
			var tempElement = actionList[comboButton.defaultAction];
			return localizer == undefined ? "defaultButton" : (tempElement.name + "Button");
		}
		objectName: makeObjectName();
        tabOrder: comboButton.tabOrder ? 1 : 0
		setFocusOnPressed: true
        focus: true
        anchors.left: parent.left
        mirror: Window.Mirror
        buttonHeight: comboButton.buttonHeight
        backgroundImage: arrowButton.visible ? comboButton.leftComboNormalImage : style.buttonNormalImage
        hoverImage: arrowButton.visible ? comboButton.leftComboHoverImage : style.buttonHoverImage
        pressedImage: arrowButton.visible ? comboButton.leftComboPressedImage : style.buttonPressedImage
        textcolor: style.textColor
        text: comboButton.defaultText
        textStyle: style.textStyle
        textStyleColor: style.textStyleColor
        horizontalMargin: comboButton.horizontalMargin
        enabled: comboButton.isDefaultEnabled;
        onClicked: comboButton.pressed(comboButton.defaultAction);
        maxWidth: comboButton.maxWidth ? comboButton.maxWidth - arrowButton.width : 0
        minWidth: comboButton.minWidth ? comboButton.minWidth - arrowButton.width : 0
        KeyNavigation.right: arrowButton
    }

    Button
    {
        id: arrowButton
		objectName: "arrowButton"
        tabOrder: comboButton.tabOrder ? 1 : 0
		setFocusOnPressed: true
        mirror: Window.Mirror
        anchors.left: textButton.right
        buttonHeight: textButton.height
        visible: actionList.length > 1
        width: visible ? comboButton.buttonRightWidth : 0
        backgroundImage: comboButton.rightComboNormalImage
        hoverImage: comboButton.rightComboHoverImage
        pressedImage: comboButton.rightComboHoverImage
        horizontalMargin: 2
        KeyNavigation.left: textButton
        onClicked:
        {
            comboButton.populateMenu();
            comboButton.menu.ShowNearItem(comboButton.getNearRect(comboButton.showMenuAtArrow ? arrowButton : textButton));
            comboButton.menu.focus = true;
            arrowButton.focus = true;
        }
    }
}
