import QtQuick 1.1
import "../fonts" as Fonts
import "../widgets" as Widgets

Item
{
    id: editableListView

    signal addElement;
    signal editElement(int index);
    signal deleteElement(int index);

    property alias model: listView.model

    property string addImage
    property string editImage
    property string deleteImage
    property string addDisabledImage: addImage
    property string editDisabledImage: editImage
    property string deleteDisabledImage: deleteImage

    property alias addText: addButton.text
    property alias editText: editButton.text
    property alias deleteText: deleteButton.text
    property string textPropertyName: ""

    height: toolImage.height

    Rectangle
    {
        id: listRect
        anchors.fill: parent

        border
        {
            width: 1
            color: "gray"
        }

        Column
        {
            objectName: "Column"
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.topMargin: 1
            anchors.leftMargin: 1
            anchors.bottom: parent.bottom

            Item
            {
                id: toolBar
                objectName: "Toolbar"
                width: parent.width
                height: toolImage.height

                BorderImage
                {
                    id: toolImage

                    source: "../images/settings/firewall/toolbar.png"

                    anchors.left: parent.left
                    anchors.right: parent.right
                    Widgets.DPIScaler {changeHeight: true}
                }

                Row
                {
                    id: toolButtons
                    anchors.left: parent.left
                    anchors.leftMargin: 1
                    anchors.verticalCenter: parent.verticalCenter
                    height: editButton.height + 4

                    objectName: "Row"

                    spacing: 2

                    Widgets.Button
                    {
                        id: addButton
                        objectName: "AddButton"

                        anchors.verticalCenter: parent.verticalCenter
                        height: 30
                        horizontalMargin: 5

                        textcolor: "#1460ff"
                        textcolorDisabled: "#a0a0a0"

                        iconImage: enabled ? addImage : addDisabledImage

                        backgroundImage: enabled ? "../images/settings/firewall/toolbar.png" : ""
                        hoverImage: "../images/settings/firewall/toolbar_hover.png"
                        pressedImage: "../images/settings/firewall/toolbar_pressed.png"
                        focusRectEnabled: false

                        FocusImage
                        {
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.horizontalCenter: parent.horizontalCenter
                            tileHorizontally: true
                            widthClipperSize: 4
                            border {
                                left: 4
                                right: 4
                            }
                            source: "../images/focuses/focus_gray_rect.png"
                        }

                        onClicked:
                        {
                            editableListView.addElement();
                        }
                    }

                    Widgets.Button
                    {
                        id: editButton
                        objectName: "EditButton"

                        anchors.verticalCenter: parent.verticalCenter
                        height: 30
                        horizontalMargin: 5

                        textcolor: "#1460ff"
                        textcolorDisabled: "#a0a0a0"

                        iconImage: enabled ? editImage : editDisabledImage

                        backgroundImage: enabled ? "../images/settings/firewall/toolbar.png" : ""
                        hoverImage: "../images/settings/firewall/toolbar_hover.png"
                        pressedImage: "../images/settings/firewall/toolbar_pressed.png"
                        focusRectEnabled: false

                        FocusImage
                        {
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.horizontalCenter: parent.horizontalCenter
                            tileHorizontally: true
                            widthClipperSize: 4
                            border {
                                left: 4
                                right: 4
                            }
                            source: "../images/focuses/focus_gray_rect.png"
                        }

                        enabled: editableListView.enabled && listView.current !== null && listView.current.canEdit

                        onClicked:
                        {
                            listView.current.editUrl();
                        }
                    }

                    Widgets.Button
                    {
                        id: deleteButton
                        objectName: "DeleteButton"

                        anchors.verticalCenter: parent.verticalCenter
                        height: 30
                        horizontalMargin: 5

                        textcolor: "#1460ff"
                        textcolorDisabled: "#a0a0a0"

                        iconImage: enabled ? deleteImage : deleteDisabledImage

                        backgroundImage: enabled ? "../images/settings/firewall/toolbar.png" : ""
                        hoverImage: "../images/settings/firewall/toolbar_hover.png"
                        pressedImage: "../images/settings/firewall/toolbar_pressed.png"
                        focusRectEnabled: false

                        FocusImage
                        {
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.horizontalCenter: parent.horizontalCenter
                            tileHorizontally: true
                            widthClipperSize: 4
                            border {
                                left: 4
                                right: 4
                            }
                            source: "../images/focuses/focus_gray_rect.png"
                        }

                        enabled: editableListView.enabled && listView.current !== null && listView.current.canDelete

                        onClicked:
                        {
                            listView.current.deleteUrl();
                        }
                    }

                }
            }

            Rectangle
            {
                width: parent.width
                height: 1
                color: "lightgray"
            }

            Item
            {
                objectName: "listViewWrapper"
                width: parent.width
                height: parent.height - toolBar.height - 1
                clip: true

                Widgets.ScrollBar
                {
                    id: userListScrollBar
                    objectName: "FlickableScrollBar";
                    anchors.top: parent.top
                    anchors.bottom: parent.bottom
                    anchors.right: parent.right

                    target: listView

                    visible: listView.contentHeight > listView.height
                }

                ListView
                {
                    id: listView
                    anchors {
                        top: parent.top
                        bottom: parent.bottom
                        left: parent.left
                        right: userListScrollBar.left
                    }

                    clip: true

                    property Item current: null

                    function getCurrentSelectColor()
                    {
                        return "#0d3256";
                    }

                    function getCurrentTextColor(itemId)
                    {
                        if (editableListView.enabled && listView.current === itemId)
                        {
                            return "white";
                        }
                        else
                        {
                            return "black";
                        }
                    }

                    onModelChanged:
                    {
                        listView.current = null
                    }

                    delegate: Item
                    {
                        id: listViewItem

                        anchors.left: parent.left
                        anchors.right: parent.right

                        height: listText.height + 4

                        property bool canEdit: true
                        property bool canDelete: true

                        function editUrl()
                        {
                            editableListView.editElement(index)
                        }

                        function deleteUrl()
                        {
                            listView.current = null
                            editableListView.deleteElement(index)
                        }

                        Rectangle
                        {
                            visible: listView.current === listViewItem
                            color: listView.getCurrentSelectColor()
                            anchors.fill: parent

                            z: -1
                        }

                        Text
                        {
                            id: listText

                            anchors.left: parent.left
                            anchors.leftMargin: 10
                            anchors.verticalCenter: listViewItem.verticalCenter

                            width: parent.width

                            color: listView.getCurrentTextColor(parent)

                            elide: Text.ElideRight
                            text: modelData[editableListView.textPropertyName]
                        }

                        MouseArea
                        {
                            anchors.fill: parent

                            acceptedButtons: Qt.LeftButton

                            onDoubleClicked: edit();
                            onClicked:
                            {
                                if (listRect.enabled)
                                {
                                    listView.current = listViewItem;
                                }
                            }
                        }

                        Widgets.DPIScaler {changeHeight: true}
                    }

                }
            }
        }
    }
}
