import QtQuick 1.1

Item
{
	id: widget

	property variant target
	property string property
	property int minValue: -2147483647
	property int maxValue: +2147483647

	visible: false

	function decrement(count)
	{
		if (!target || !property)
			return;
		var currentValue = target[property];
		if (currentValue == minValue)
			return;
		if (currentValue - minValue > count)
			target[property] = currentValue - count;
		else
			target[property] = minValue;
	}
	function increment(count)
	{
		if (!target || !property)
			return;
		var currentValue = target[property];
		if (currentValue == maxValue)
			return;
		if (maxValue - currentValue > count)
			target[property] = currentValue + count;
		else
			target[property] = maxValue;
	}
	function start(func)
	{
		timer.func = func;
		timer.stepSizeIndex = 0;
		timer.prepareNextStep();
		timer.start();
	}
	function stop()
	{
		timer.stop();
	}

	Timer
	{
		id: timer

		property string func

		property variant stepSizes: [1, 5, 20, 100] // first element must be 1, each element must be divisable by previous

		property int stepSizeIndex
		property int stepsToNextStepSize

		function prepareNextStep()
		{
			if (stepSizeIndex == stepSizes.length - 1)
				return;
			var currentValue = target[property] * (func == "decrement" ? -1 : 1);
			var currentStepSize = stepSizes[stepSizeIndex];
			var nextStepSize = stepSizes[stepSizeIndex + 1];
			var nextStepSizeValue = (Math.ceil(currentValue / nextStepSize) + 2) * nextStepSize;
			stepsToNextStepSize = (nextStepSizeValue - currentValue) / currentStepSize;
		}

		interval: 100
		repeat: true
		triggeredOnStart: true
		onTriggered:
		{
			widget[func](stepSizes[stepSizeIndex]);
			if (stepSizeIndex < stepSizes.length - 1 && --stepsToNextStepSize <= 0)
			{
				++stepSizeIndex;
				prepareNextStep();
			}
		}
	}
}
