import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets

Item
{
	id: view
	objectName: "toolList"
    height: 145
	Widgets.DPIScaler { changeHeight: true }

	// public
	signal activate(string panelName)
	property bool canLeft:  !firstScreen
	property bool canRight: !lastScreen

	function doLeft()
	{
		if (canLeft)
		{
			--currentScreen;
			view.invalidateFocus();
		}
		else
		{
			++currentScreen;
			view.invalidateFocus();
		}
	}

	function doRight()
	{
		if (canRight)
		{
			++currentScreen;
			view.invalidateFocus();
		}
		else
		{
			--currentScreen;
			view.invalidateFocus();
		}
	}

	// private
	property int featuresPerRow: 5
    property int cellWidth: width / featuresPerRow
    property int cellHeight: 68
	property int currentScreen: 0
	property int screenCount: Math.ceil(listView.count / featuresPerRow)
	property bool firstScreen: currentScreen == 0
    property bool lastScreen: currentScreen + 1 == screenCount
	property alias focusIndex: listView.focusIndex
	property alias activeFocus: listView.activeFocus
	function setActiveFocus()
	{
		listView.forceActiveFocus();
		view.updateScreenIndexFromItemIndex(listView.focusIndex);
	}
	function screenIndexFromItemIndex(index)
	{
		return Math.floor(index / view.featuresPerRow);
	}
	function updateScreenIndexFromItemIndex(index)
	{
		if ((listView.currentIndex > index) || ((listView.currentIndex + view.featuresPerRow) <= index))
			view.currentScreen = screenIndexFromItemIndex(index);
	}
	function invalidateFocus()
	{
		if (view.currentScreen != screenIndexFromItemIndex(listView.focusIndex))
			listView.focusIndex = listView.currentIndex;
	}
	ListView
    {
        id: listView
		objectName: "toolListView"
		property int focusIndex: 0
		property int tabOrder: 1
		clip: true
        anchors.horizontalCenter: parent.horizontalCenter
		anchors.verticalCenter:   parent.verticalCenter
        anchors.verticalCenterOffset : -10 * dpiScaler.factor
        delegate: Item
        {
            width: view.cellWidth;
            height: view.cellHeight;

            ToolListItem
            {
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 30
                defaultArrowsProcessing: false
                Widgets.DPIScaler{changeHeight:true}
                onActivate: view.activate(panelName)
                onRightPressed:
                {
                    if (listView.count - 1 > listView.focusIndex)
                    {
                        view.updateScreenIndexFromItemIndex(listView.focusIndex + 1);
                        ++listView.focusIndex;
                    }
                }
                onLeftPressed:
                {
                    if (listView.focusIndex)
                    {
                        view.updateScreenIndexFromItemIndex(listView.focusIndex - 1);
                        --listView.focusIndex;
                    }
                }
                onDownPressed:
                {
                    if (!view.lastScreen)
                        view.doRight();
                }
                onUpPressed:
                {
                    if (!view.firstScreen)
                        view.doLeft();
                }
            }
        }

		height: (parent.height * 0.85) + 8
		width: parent.width
		model: MainWindow.toolsList
		orientation: ListView.Horizontal
		interactive: false
        preferredHighlightBegin: Window.Mirror ? width : 0
        preferredHighlightEnd: Window.Mirror ? width  - cellWidth : view.cellWidth
        highlightRangeMode: ListView.ApplyRange
		function calculateCurrentIndex()
		{
			var index = view.currentScreen * view.featuresPerRow;
			var extraItems = index + view.featuresPerRow - listView.count;
            var currentIndex = (view.currentScreen && view.lastScreen) ? (index - extraItems) : index;
            var originalCurrentIndex = currentIndex
            if (Window.Mirror)
            {
                // hack - prefferedHighlight don't work for mirrored layouts as expected
                if (currentIndex != lastCurrentIndex) {
                    from0 = currentIndex > lastCurrentIndex
                }
                if (from0) {
                    currentIndex += view.featuresPerRow - 1
                }
            }
            lastCurrentIndex = originalCurrentIndex
            return currentIndex
		}
        property bool from0: true
        property int lastCurrentIndex: 0
		currentIndex: calculateCurrentIndex()
        highlightMoveSpeed: 1200
	}

	Row
	{
		anchors.bottom: parent.bottom
        anchors.bottomMargin: 30
		anchors.horizontalCenter: listView.horizontalCenter
        anchors.horizontalCenterOffset: - 5
		objectName: "row"
		Repeater
		{
			model: view.screenCount
			objectName: "repeater"
			Widgets.Button
			{
				tabOrder: 0
				objectName: "DotButton" + index
                iconImage: "../images/main_window/featurebox/center_switches_" + (view.currentScreen == index ? "selected" : "normal") + ".png"
                iconHoverImage: "../images/main_window/featurebox/center_switches_selected.png"
                buttonWidth: 13
				onClicked: 
				{
					view.currentScreen = index;
					view.invalidateFocus();
				}
			}
		}
	}

	MouseWheelArea
	{
		anchors.fill: parent
		onVerticalWheel: wheel(delta)
		onHorizontalWheel: wheel(delta)
		function wheel(delta)
		{
			if (canLeft && delta > 0)
				doLeft()
			else if (canRight && delta < 0)
				doRight()
		}
	}
}

