import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../main_window" as MainFrame
import "../common/HelpMapper.js" as HelpMapper

MainFrame.InnerContent
{
	Localizer { id:tr; scope:"MainWindow" }
	caption: tr.Localize("ProblemListPanelName")
    property int helpId: HelpMapper.ProblemListHelpId
	objectName:	"problemList"

    captionArea: Component
    {
        Item
        {
            clip: false
            objectName:	"captionArea"
            Localizer { id:itemLocalizer; scope:"ProblemList" }

            Row
            {
                anchors.verticalCenter: parent.verticalCenter
                anchors.right: parent.right
                anchors.rightMargin: 8
                anchors.verticalCenterOffset: 1
                spacing: 5

                Repeater
                {
                    objectName: "groupActions"
                    model: MainWindow.problemList.groups

                    Widgets.ComboButton
                    {
                        objectName: "action"
                        actionList: modelData.actions
                        property QtObject tempElement
                        enabled: !modelData.areActionsDisabled
                        localizer: itemLocalizer
						visible: modelData.actions.length > 0
                        leftComboNormalImage: "../images/inner/header_button_normal_left.png"
                        leftComboHoverImage: "../images/inner/header_button_hover_left.png"
                        leftComboPressedImage: "../images/inner/header_button_pressed_left.png"
                        rightComboNormalImage: "../images/inner/header_button_normal_right.png"
                        rightComboHoverImage: "../images/inner/header_button_hover_right.png"
                        rightComboPressedImage: "../images/inner/header_button_pressed_right.png"
                        horizontalMargin: 10
                        buttonHeight: 26
                        buttonRightWidth: 27

                        onPressed:
                        {
                            if (index < actionList.length)
                            {
                                tempElement = actionList[index];
                                if (tempElement.action != undefined)
                                    tempElement.action.Invoke(modelData.itemIndex)
                            }
                        }
                    }
                }
            }
        }
	}

	viewArea : Component
	{
        Rectangle
		{
			objectName:	"viewArea"
			property variant commonFontStyles: Fonts.Common{}
			QtObject
			{
				id:style
				// style properties for section header
				property color sectionHeaderColor: "#ededed"

				// style properties for item delegate
				property color itemColor: "transparent"
				property color itemBorderColor: "transparent"
			}

			anchors.fill: parent
            clip: true;

			Widgets.EmptyListText
			{
				id: emptyListText
				text: tr.Localize("ProblemListNoProblem")
				visible: !virtualList.visible
			}

			Localizer { id:itemLocalizer; scope:"ProblemList" }
			Component
			{
				id: itemDelegate
                ProblemListItem	{ localizer:itemLocalizer }
			}
			
			Component
			{
				id: sectionDelegate
				SectionHeader { }
			}
					
			GroupedVirtualList
			{
				id: virtualList
				objectName:	"groupedVirtualList"
                anchors.left: parent.left
                anchors.right: scroller.left
                height: parent.height
				model: MainWindow.problemList
				delegate: itemDelegate
				sectionDelegate: sectionDelegate
				Widgets.DpiScaler { id: dpiScaler }
				property real unit: dpiScaler.factor
                itemHeights: [129 * unit, 129 * unit, 129 * unit, 129 * unit, 129 * unit, 129 * unit ]
				sectionHeight: 0 * unit
				focus: true
                clip: visible
				visible: contentHeight > 0

                onVisibleChanged: returnToBounds()
			}

            Widgets.ScrollBar
            {
                id: scroller
                height: parent.height
                anchors.right: parent.right
                target: virtualList
            }
		}
	}
}

