import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../common/border" as Border
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/Margins.js" as Margins
import "../common/EnumHelper.js" as EnumHelper
import "../common/HelpMapper.js" as HelpMapper

Border.BorderedContent
{
    content: safeBankingRulesDialog

    property variant context: SafeBankingRulesDialog
    property variant commonFontStyles: Fonts.Common{}
    property bool isDefaultSettingsEditMode: EnumHelper.getKey(context, "editMode") === "Default"
    property bool isSafeMoneyTargetScreen: EnumHelper.getKey(context, "targetScreen") === "SafeMoneyScreen"

    Widgets.SecondaryWindow
    {
        id: safeBankingRulesDialog
        objectName: "SafeBankingRulesWindow"
        width: 350
        height: isDefaultSettingsEditMode ? 220 : (isSafeMoneyTargetScreen ? 280 : 350)
        Localizer { id: tr; scope: "SafeBankingRulesDialog" }
        caption: tr.Localize("Caption" + EnumHelper.getKey(context, "editMode"));

        workArea: FocusScope
        {
            objectName: "WorkArea"

            Column
            {
                id: safeBankingColumn

                anchors.fill:parent

                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: Margins.verticalCommonTextToWidget

                spacing: 10

                Text
                {
                    id: urlLabel
                    visible: !isDefaultSettingsEditMode

                    anchors.left: parent.left

                    font: commonFontStyles.standardCommonTextFont
                    horizontalAlignment: Text.AlignLeft

                    text: tr.Localize("UrlLabel");
                }

                Widgets.UrlEditBox
                {
                    focus: true
                    visible: !isDefaultSettingsEditMode

                    anchors.left: parent.left
                    anchors.right: parent.right

                    target: context
                    property: "url"

                    scheme: "https://"

                    tabOrder: 0
                }

                Text
                {
                    id: titleLabel

                    anchors.left: parent.left
                    visible: !isDefaultSettingsEditMode

                    font: commonFontStyles.standardCommonTextFont
                    horizontalAlignment: Text.AlignLeft

                    text: tr.Localize("TitleLabel");
                }

                Widgets.EditBox
                {
                    visible: !isDefaultSettingsEditMode

                    anchors.left: parent.left
                    anchors.right: parent.right

                    target: context
                    property: "title"

                    tabOrder: 1
                }

                Text
                {
                    id: actionLabel

                    visible: !isSafeMoneyTargetScreen

                    anchors.left: parent.left
                    anchors.right: parent.right

                    font: commonFontStyles.standardCommonTextFontBold
                    horizontalAlignment: Text.AlignLeft
                    wrapMode: Text.WordWrap

                    text: isDefaultSettingsEditMode ? tr.Localize("DefaultSettingsLabel") : tr.Localize("ActionLabel");
                }

                Widgets.EnumRadioGroup
                {
                    visible: !isSafeMoneyTargetScreen

                    anchors.left: parent.left
                    anchors.leftMargin: 5

                    horizontalMargin: 7

                    target: context
                    property: "actionType"
                    localizer: tr
                    spacing: 6
                }
            }
        }

        buttonsArea: FocusScope
        {
            id: bottomRow
            anchors.fill: parent
            objectName: "bottom"
            property int tabOrder: 2
            property int helpId: isDefaultSettingsEditMode ? HelpMapper.SafeBankingDefaultRulesDialogHelpId : HelpMapper.SafeBankingRulesDialogHelpId


            Widgets.HelpButton
            {
                anchors
                {
                    verticalCenter: parent.verticalCenter
                    left: parent.left
                    leftMargin: 12
                }

                objectName: "help"
                text: tr.Localize("Help")
                onClicked: Help.Show(bottomRow.helpId)
            }

            Widgets.GrayButton
            {
                id: okButton

                setAsDefaultButton: true
                minWidth: cancelButton.width
                enabled: (context.urlCorrect && !context.hostExist) || EnumHelper.getKey(context, "editMode") === "Default"

                anchors
                {
                    verticalCenter: parent.verticalCenter
                    right: cancelButton.left
                    rightMargin: Margins.horizontalBetweenButtons
                }

                objectName: "OkButton"
                text: tr.Localize("OK")
                onClicked:
                {
                    context.dialogResult = 0;
                    Window.Close();
                }
            }

            Widgets.GrayButton
            {
                id: cancelButton

                anchors
                {
                    verticalCenter: parent.verticalCenter
                    right: parent.right
                }

                objectName: "CancelButton"
                text: tr.Localize("Cancel")
                onClicked:
                {
                    context.dialogResult = 1;
                    Window.Close()
                }
            }
        }

        Widgets.DPIScaler {
            id: dpiScaler
            changeHeight: true
        }
    }
}
