import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "AntiBanner"

    property int helpId: HelpMapper.AntiBannerSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "AntiBanner")
    property variant fontStyles: Fonts.Common{}

    Localizer { id: tr; scope: "AntiBannerSettings" }

    Column
    {
        objectName: "MainWrapper"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "GeneralAntiBannerSection"
            body: Column {
                width: parent.width
                objectName: "GeneralAntiBanner"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                }

                SettingsCommon.CheckBox
                {
                    anchors.left: parent.left
                    objectName: "EnableAntiBanner"
                    text: tr.Localize("UseAntiBanner")
                    isBold: true
                    target: context
                    property: "enableAntiBanner"
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "ScanMethodsSection"
            name: tr.Localize("ScanMethods")
            enabled: context.enableAntiBanner
            body: Column
            {
                objectName: "ScanMethods"
                width: parent.width
                spacing: Margins.settingsCheckboxSpacing

                SettingsCommon.CheckBox
                {
                    objectName: "UseDatabase"
                    text: tr.Localize("UseCommonBannerList")
                    target: context
                    property: "useDatabase"
                    anchors.left: parent.left
                }

                SettingsCommon.CheckBox
                {
                    objectName: "ResolveIp"
                    text: tr.Localize("ResolveIPs")
                    target: context
                    property: "resolveIPs"
                    anchors.left: parent.left
                }

                SettingsCommon.CheckBox
                {
                    objectName: "useHeuristics"
                    text: tr.Localize("UseHeuristicAnalysis")
                    target: context
                    property: "useHeuristics"
                    anchors.left: parent.left
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "AdditionalSection"
            name: tr.Localize("Additional")
            enabled: context.enableAntiBanner
            body: Column
            {
                objectName: "Additional"
                width: parent.width
                spacing: Margins.settingsInnerSpacing

                Column
                {
                    anchors.left: parent.left
                    objectName: "BlackListWrapper"
                    width: parent.width
                    spacing: Margins.settingsBeforeButtonSpacing

                    SettingsCommon.CheckBox
                    {
                        objectName: "UseBlackList"
                        anchors.left: parent.left
                        text: tr.Localize("UseBlackList")
                        target: context
                        property: "useBlackList"
                    }

                    SettingsCommon.SettingsButton
                    {
                        objectName:"BlackList"
                        anchors.left: parent.left
                        text: tr.Localize("SettingsMore")
                        enabled: context.openBlackListSettingsEnabled
                        onClicked: context.OpenBlackListSettings()
                    }

                }


                Column
                {
                    objectName: "WhiteListWrapper"
                    width: parent.width
                    anchors.left: parent.left
                    spacing: Margins.settingsBeforeButtonSpacing

                    SettingsCommon.CheckBox
                    {
                        objectName: "UseWhiteList"
                        anchors.left: parent.left
                        text: tr.Localize("UseWhiteList")
                        target: context
                        property: "useWhiteList"
                    }

                    SettingsCommon.SettingsButton
                    {
                        objectName:"WhiteList"
                        anchors.left: parent.left
                        text: tr.Localize("SettingsMoreWhite")
                        enabled: context.openWhiteListSettingsEnabled
                        onClicked: context.OpenWhiteListSettings()
                    }
                }
            }
        }
    }
}
