import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../../common/ProductTypeHelper.js" as ProductTypeHelper
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "AppearancePage"

    property int helpId: HelpMapper.AppearanceSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "Appearance")
    property variant fontStyles: Fonts.Common{}
    Localizer { id: tr; scope: "AppearanceSettings" }

    Column
    {
        objectName: "MainWrapper"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "AppearanceGeneralSection"
            body: Column
            {
                objectName: "AppearanceGeneral"
                spacing: Margins.settingsSectionInnerSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description_" + ProductTypeHelper.productTypeToString(context))
                    wrapMode: Text.Wrap
                }

                Column
                {
                    objectName: "SkinBlock"
                    visible: true
                    spacing: Margins.settingsSectionInnerSpacing
                    width: parent.width

                    SettingsCommon.CheckBox
                    {
                        objectName: "UseSkin"
                        anchors.left: parent.left
                        text: tr.Localize("UseSkin")
                        target: context
                        property: "enableSkinPath"
                        isBold: true
                    }

                    Item
                    {
                        objectName: "SkinRow"
                        width: parent.width
                        height: childrenRect.height
                        enabled: context.enableSkinPath

                        Widgets.EditBox
                        {
                            target: context
                            property: "skinPath"
                            anchors.left: parent.left
                            anchors.right: skinBrowse.left
                            anchors.rightMargin: 10
                        }

                        SettingsCommon.SettingsButton
                        {
                            id: skinBrowse
                            text: tr.Localize("Browse")
                            anchors.right: parent.right
                            onClicked: context.BrowseSkin()
                        }
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        text: tr.Localize("SkinPathIsEmpty")
                        anchors.left: parent.left
                        anchors.leftMargin: 20
                        visible: context.enableSkinPath && context.skinPathEmpty
                        color: "red"
                    }
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "InterfaceLanguage"
            visible: context.canChangeLocalization
            name: tr.Localize("InterfaceLanguage")
            body: Widgets.ListCombo
            {
                anchors.left: parent.left
                anchors.leftMargin: 20
                target: context
                property: "selectedLocalization"
                keyList: context.localizations
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "PanelIcon"
            name: tr.Localize("PanelIcon")
            body: Column
            {
                objectName: "PanelIconColumn"
                spacing: Margins.settingsCheckboxSpacing

                SettingsCommon.CheckBox
                {
                    objectName: "AnimatePanelIcon"
                    anchors.left: parent.left

                    text: tr.Localize("AnimatePanelIcon");
                    target: context
                    property: "animatePanelIcon"
                }

                SettingsCommon.CheckBox
                {
                    objectName: "UseWindowOpacity"
                    anchors.left: parent.left

                    text: tr.Localize("UseWindowOpacity");
                    target: context
                    property: "useWindowOpacity"
                }

                SettingsCommon.CheckBox
                {
                    objectName: "ShowProtectedMessage"
                    anchors.left: parent.left

					visible: context.canShowEnableLoginShow;
                    text: tr.Localize("ShowProtectedMessage");
                    wrapMode: Text.Wrap
                    target: context
                    property: "enableLoginShow"
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "NewsNotificateSection"
            width: parent.width

            body: Column
            {
                objectName: "NewsNotificateWrapper"

                SettingsCommon.CheckBox
                {
                    objectName: "NewsNotificate"
                    anchors.top: parent.top
                    anchors.topMargin: 10
                    anchors.left: parent.left

                    text: tr.Localize("NewsNotificate");
                    target: context
                    property: "enableNews"
                }
            }

        }
    }
}
