import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "NotificationsPage"

    property int helpId: HelpMapper.NotificationsSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "Notifications")
    property variant fontStyles: Fonts.Common{}
    Localizer { id: tr; scope: "NotificationsSettings" }

    Column
    {
        width: parent.width
        height: parent.height
        spacing: Margins.settingsPageSpacing
        objectName: "MainWrapper"

        SettingsCommon.SettingsSection
        {
            objectName: "NotificationsGeneralSection"
            body: Column
            {
                objectName: "NotificationsGeneral"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                }

                Column
                {
                    objectName: "NotificateEventsColumn"
                    width: parent.width
                    spacing: Margins.settingsBeforeButtonSpacing

                    SettingsCommon.CheckBox
                    {
                        id: notificateEvents
                        anchors.left: parent.left

                        objectName: "NotificateEvents"
                        text: tr.Localize("NotificateEvents")
                        isBold: true
                        target: context
                        property: "notificateEvents"
                    }

                    SettingsCommon.SettingsButton
                    {
                        objectName: "SettingsMore"
                        anchors.left: parent.left
                        text: tr.Localize("SettingsMore")
                        enabled: context.notificateEvents
                        onClicked: context.EditNotificationSettings()
                    }
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "MailNotifications"
            name: tr.Localize("MailNotifications")
            body: Column
            {
                objectName: "SendMailNotificationsColumn"
                spacing: Margins.settingsBeforeButtonSpacing

                SettingsCommon.CheckBox
                {
                    id: sendMailNotifications
                    anchors.left: parent.left

                    objectName: "SendMailNotifications"
                    text: tr.Localize("SendMailNotifications")
                    isBold: true
                    enabled: context.notificateEvents
                    target: context
                    property: "sendMailNotifications"
                }

                SettingsCommon.SettingsButton
                {
                    objectName: "SettingsMore"
                    anchors.left: parent.left
                    text: tr.Localize("MailSettingsMore")
                    enabled: parent.enabled && context.sendMailNotifications
                    onClicked: context.EditMailSettings()
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "SoundNotifications"
            name: tr.Localize("SoundNotifications")
            body: Column
            {
                spacing: Margins.settingsCheckboxSpacing

                SettingsCommon.CheckBox
                {
                    id: useSoundNotifications
                    anchors.left: parent.left

                    objectName: "UseSoundNotifications"
                    text: tr.Localize("UseSoundNotifications")
                    isBold: true
                    enabled: context.notificateEvents
                    target: context
                    property: "useSoundNotifications"
                }

                SettingsCommon.CheckBox
                {
                    objectName: "UseStandardSounds"
                    anchors.left: parent.left
                    anchors.leftMargin: useSoundNotifications.baseWidth - useSoundNotifications.textMargin
                    text: tr.Localize("UseStandardSounds")
                    enabled: useSoundNotifications.enabled && context.useSoundNotifications
                    target: context
                    property: "useStandardSounds"
                }
            }
        }
    }

    Row
    {
        spacing: 7
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 5
        width: parent.width
	visible: context.isGamingProfileEnabled && context.notificateEvents

        Image
        {
            id: warning
            source: "../../common/images/ico_warning_16.png"
        }

        SettingsCommon.SettingsStandardText
        {
            text: tr.Localize("NotificationsWarning")
            width: parent.width - warning.width - 7
            wrapMode: Text.Wrap
        }
    }
}
