import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../../common/ProductTypeHelper.js" as ProductTypeHelper
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "SelfDefencePage"

    property int helpId: HelpMapper.SelfDefenceSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "SelfDefence")
    property variant fontStyles: Fonts.Common{}
    Localizer { id: tr; scope: "SelfDefenceSettings" }

    Column
    {
        objectName: "MainWrapper"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "SelfDefenceGeneralSection"

            body: Column
            {
                objectName: "SelfDefenceGeneral"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                }

                Column
                {
                    objectName: "SelfDefenceColumn"
                    width: parent.width
                    spacing: Margins.settingsAfterTextSpacing
                    visible: context.protectionInstalled

                    SettingsCommon.CheckBox
                    {
                        id: selfDefence
                        objectName: "SetSelfDefence"
                        anchors.left: parent.left

                        text: tr.Localize("SetSelfDefence");
                        isBold: true
                        target: context
                        property: "enableSelfProtection"
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        anchors.left: parent.left
                        anchors.leftMargin: selfDefence.textMargin
                        width: parent.width - anchors.leftMargin
                        text: tr.Localize("SetSelfDefenceDescription_" + ProductTypeHelper.productTypeToString(context))
                        wrapMode: Text.Wrap
                    }

                    Row
                    {
                        spacing: 7
                        width: parent.width - anchors.leftMargin
                        anchors.left: parent.left
                        anchors.leftMargin: selfDefence.textMargin
                        visible: !context.enableSelfProtection && (dangerText.text != "")

                        Image
                        {
                            id: danger
                            source: "../../common/images/ico_danger_16.png"
                        }

                        SettingsCommon.SettingsStandardText
                        {
                            id: dangerText
                            width: parent.width - danger.width - anchors.leftMargin
                            text: tr.Localize("SetSelfDefenceDescriptionOff_" + ProductTypeHelper.productTypeToString(context))
                            wrapMode: Text.Wrap
                            color: "red"
                        }
                    }
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "ExternalControl"
            name: tr.Localize("ExternalControl")
            body: Column
            {
                objectName: "ExternalControlColumn"
                spacing: Margins.settingsAfterTextSpacing

                SettingsCommon.CheckBox
                {
                    id: externalControl
                    objectName: "UnsetExternalControl"

                    text: tr.Localize("UnsetExternalControl");
                    isBold: true
                    target: context
                    property: "allowServiceStop"
                    inverted: true
                    anchors.left: parent.left
                }

                SettingsCommon.SettingsStandardText
                {
                    anchors.left: parent.left
                    anchors.leftMargin: externalControl.textMargin
                    width: parent.width - anchors.leftMargin
                    text: tr.Localize("UnsetExternalControlDescription")
                    wrapMode: Text.Wrap
                }
            }
        }
    }
}
