import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "ThreatsAndExclusionSettingsPage"

    property int helpId: HelpMapper.ThreatsAndExclusionSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "ThreatsAndExclusion")
    property variant fontStyles: Fonts.Common{}
    Localizer { id: tr; scope: "ThreatsAndExclusionSettings" }

    Column
    {
        objectName: "MainWrapper"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "ThreatsAndExclusionGeneralSection"
            body: Column
            {
                objectName: "ThreatsAndExclusionGeneral"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                }

                Column
                {
                    objectName: "ThreatsWrapper"
                    width: parent.width
                    spacing: Margins.settingsBeforeButtonSpacing

                    Column
                    {
                        objectName: "Threats"

                        width: parent.width
                        spacing: 5

                        SettingsCommon.SettingsStandardText
                        {
                            anchors.left: parent.left
                            width: parent.width
                            isBold: true
                            text: tr.Localize("ThreatsDescription")
                            wrapMode: Text.Wrap
                        }

                        function buildKey(map)
                        {
                            var result = ""
                            for (var key in map)
                                result += context[key] ? map[key] : "";
                            return result;
                        }

                        SettingsCommon.SettingsStandardText
                        {
                            anchors.left: parent.left
                            width: parent.width
                            text: tr.Localize("Malware" + parent.buildKey( { "detectMaliciousTools" : "Malicious" } ));
                            wrapMode: Text.Wrap
                        }

                        SettingsCommon.SettingsStandardText
                        {
                            anchors.left: parent.left
                            width: parent.width
                            property string key: parent.buildKey( {
                                "detectAdware" : "Adware",
                                "detectAutoDialers" : "Dialers",
                                "detectOther" : "Other" });
                            text: key ? tr.Localize(key) : ""
                            visible: key
                            wrapMode: Text.Wrap
                        }

                        SettingsCommon.SettingsStandardText
                        {
                            anchors.left: parent.left
                            width: parent.width
                            property string suffix: parent.buildKey( {
                                "detectUnknownPackages" : "Unknown",
                                "detectMultiPackedObjects" : "Multi" } );
                            text: suffix ? tr.Localize("Packagers" + suffix) : ""
                            visible: suffix
                            wrapMode: Text.Wrap
                        }
                    }

                    SettingsCommon.SettingsButton
                    {
                        objectName: "SetThreats"
                        anchors.left: parent.left
                        text: tr.Localize("TreatsSettingsMore")
                        onClicked: context.OpenThreatsSettings()
                    }
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "Exclusions"
            name: tr.Localize("Exclusions")
            body:

            Column
            {
                objectName: "ExclusionsWrapper"
                spacing: Margins.settingsBeforeButtonSpacing

                Column
                {
                    spacing: 7
                    objectName: "ExclusionsColumn"
                    width: parent.width

                    SettingsCommon.SettingsStandardText
                    {
                        anchors.left: parent.left
                        width: parent.width
                        text: tr.Localize("Rules", {
                            "EnabledRuleCount" : context.enabledRuleCount,
                            "TotalRuleCount" : context.totalRuleCount })
                        wrapMode: Text.Wrap
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        anchors.left: parent.left
                        width: parent.width
                        text: tr.Localize("TrustedApplications", {
                            "TrustedApplicationCount" : context.trustedApplicationCount,
                            "TotalApplicationCount" : context.totalApplicationCount })
                        wrapMode: Text.Wrap
                    }
                }

                SettingsCommon.SettingsButton
                {
                    objectName: "SetExclusions"
                    text: tr.Localize("ExlusionSettingsMore")
                    anchors.left: parent.left
                    onClicked: context.OpenExlusionsSettings()
                }
            }
        }
    }
}
