import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/EnumHelper.js" as EnumHelper

Item
{
	height: childrenRect.height
	width: childrenRect.width
	Text
	{
		function getTaskName(object, componentType)
		{
			if(object === undefined || object === null)
				return "";
			return EnumHelper.convert(object, componentType, {
				"Idle":"TaskManager_IdleScan",
				"Full":"TaskManager_FullScan",
				"Vulnerability":"TaskManager_VulnerabilityScan",
				"CriticalArea":"TaskManager_CriticalAreaScan",
				"CustomArea":"TaskManager_CustomScan",
				"ActiveThreatCure":"TaskManager_ActiveThreatCure",
				"QScan":"TaskManager_QScan",
				"Unknown":""});
		}
		Localizer { id:tr; scope:"ScanTask" }
		id:				title
		text: 			tr.Localize(getTaskName(taskModel, "Type"));
		color:			"black";
		font:			commonFontStyles.standardSmallCaptionFont
		horizontalAlignment: Text.AlignLeft
	}
	Item
	{
		id:			progressInfo
		objectName: "progressInfo"
		anchors.left: title.right
		anchors.leftMargin: 10
		anchors.verticalCenter: title.verticalCenter
		Widgets.ConditionalLoader
		{
			anchors.verticalCenter: parent.verticalCenter
			anchors.left: parent.left
            conditionSourceComponent: Text
			{
				text: 		(taskModel.IsRunning ? taskModel.CompletionPercent : 0) + "%";
				color: 		EnumHelper.getKey(taskModel, "Type") == "ActiveThreatCure" ? "Red" : "Gray";
				font:		commonFontStyles.standardSmallCaptionFont
				horizontalAlignment: Text.AlignLeft
			}
			when: taskModel.IsRunning
		}

		Widgets.ConditionalLoader
		{
			objectName: "progressLoader"
			anchors.left: 		parent.left;
			anchors.verticalCenter: parent.verticalCenter
			anchors.verticalCenterOffset: -2
            conditionSourceComponent: Image
			{
				source: "../common/images/key_check.png"
			}
			when: taskModel.IsCompleted;
		}
	}
}
