import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/Common.js" as Common
import "../common/EnumHelper.js" as EnumHelper
import "../common/HelpMapper.js" as HelpMapper

ActivationBasePage
{
	id: page

	Localizer { id:tr; scope:"LicenseManager" }

	property bool lastChangeCorrect: true
	property bool serialNumberFullAndIncorrect: serialNumber.isFull() &&
				!context.IsActivationCodeValid &&
				EnumHelper.getKey(context.ActivationPageEdition, "LicenseType") == "LicenseTypeCommercial"

	function showTrialBlock()
	{
		return context.ActivationPageEdition.TrialActivationAvailable;
	}

	objectName: "activationPageEdition"
	headerString:			showTrialBlock() ? tr.Localize("SelectionOfActivationTypeHeader") : tr.Localize("ProlongationOfActivationHeader")
	nextButtonEnabled:		context.ActivationPageEdition.IsNextEnabled

	onAnimationCompleted: serialNumber.setFocus();

	function getHelpId()
	{
		return HelpMapper.ActivationBasePageHelpId;
	}

	Widgets.RadioGroup		{id: selectionForActivationType}

	Widgets.RadioButton
	{
		id:					selectionForCommercialLicense
		objectName: "selectionForCommercialLicense"
		anchors.top:		parent.top
		anchors.left:		parent.left
		color: 				"transparent"
		horizontalMargin:	7
		textfont:			activationWizard.fontStyles.checkBoxTextNormal
		text:				tr.Localize("SelectCommercialActivation")
		checked:			EnumHelper.getKey(context.ActivationPageEdition, "LicenseType") == "LicenseTypeCommercial"
		group:				selectionForActivationType
		visible:			showTrialBlock()
		textVerticalMargin: -1
		onCheckedChanged:
		{
			if (checked)
			{
				context.ActivationPageEdition.LicenseType = "LicenseTypeCommercial";
				if(!context.ActivationPageEdition.isActivationCodeReadOnly)
					context.ActivationCode = serialNumber.serialNumberText;
				serialNumber.setFocus();
			}
			else
			{
				serialNumber.setFocusOff();
			}
		}
	}
	Item
	{
		id: commercialActivationBlock
		objectName: "commercialActivationBlock"
		anchors.top:		selectionForCommercialLicense.visible ? selectionForCommercialLicense.bottom : parent.top
		anchors.topMargin:	selectionForCommercialLicense.visible ? 18 : 0
		anchors.left:		parent.left
		anchors.leftMargin: selectionForCommercialLicense.visible ? 24 : 0
		anchors.right:		parent.right
		height: childrenRect.height
		Column
		{
			id:					serialNumberBlock
			objectName: "serialNumberBlock"
			width:				parent.width
			anchors.left:		parent.left

			spacing:			12

			Row
			{
				spacing: 10
				anchors.left:		parent.left
				Text
				{
					id:		textForSerialNumber
					objectName: "textForSerialNumber"
					text:	tr.Localize("EnterActivationCode")
					font:	activationWizard.fontStyles.masterOfActivationButtonsNormalText
					horizontalAlignment: Text.AlignLeft
				}
				Widgets.Hyperlink
				{
					id: 	helpTextForSerialNumber
					objectName: "helpLinkForSerialNumber"
					text:	tr.Localize("SerialNumberHelpString")

					onClicked: Window.OpenURL(context.ActivationPageEdition.activationCodeHintLink);
				}
			}
			Item
			{
				anchors.left:parent.left
				anchors.right:parent.right

				height:serialNumber.height

				SerialNumber
				{
					id: serialNumber
					objectName: "serialNumber"
					anchors.left:		parent.left
					property string activationCode: context.ActivationCode
					state: page.serialNumberFullAndIncorrect ? "highlight" : ""
					onEnabledChanged:
					{
						if (enabled && selectionForCommercialLicense.checked)
							serialNumber.setFocus();
					}

					Component.onCompleted:
					{
						if (context.ActivationCode.length !== 0)
							serialNumberText = context.ActivationCode;
						serialNumber.setFocus();
					}
					onInputActiveFocusChanged:
					{
						if (inputActiveFocus)
							selectionForCommercialLicense.checked = true;
					}
					onSerialNumberChanged: lastChangeCorrect = acceptable
				}
				function setContextActivationCode()
				{
					if (!context.ActivationPageEdition.isActivationCodeReadOnly)
						context.ActivationCode = activationCodeFromSerialNumber
				}
				property string activationCodeFromSerialNumber: serialNumber.isFull() ? serialNumber.serialNumberText : ""
				onActivationCodeFromSerialNumberChanged: setContextActivationCode();
				onVisibleChanged:
				{
					if (visible && !context.ActivationCode)
						setContextActivationCode();
				}
				Item
				{
					id: activationCodeInputErrorBlock

					visible: page.serialNumberFullAndIncorrect || !lastChangeCorrect

					anchors.left: serialNumber.right; anchors.leftMargin:10
					anchors.right: parent.right;
					anchors.verticalCenter: serialNumber.verticalCenter
					height:parent.height + 10

					Image
					{
						id: warningIcon
						anchors.left: parent.left;
						anchors.verticalCenter: parent.verticalCenter
						source: "../common/images/ico_warning_16.png"
					}
					Text
					{
						id: textForInputError
						objectName: "textForInputError"
						anchors.left: warningIcon.right; anchors.leftMargin: 5
						anchors.right: parent.right;

						height:parent.height

						anchors.verticalCenter: parent.verticalCenter

						verticalAlignment:	Text.AlignVCenter

						text:	serialNumberFullAndIncorrect ? tr.Localize("ActivationCodeInputError") : tr.Localize("ActivationCodeIncorrectSymbol")
						font:	activationWizard.fontStyles.masterOfActivationButtonsNormalText
						wrapMode: Text.Wrap
						horizontalAlignment: Text.AlignLeft
					}
				}
			}
		}
		Column
		{
			id: purchaseBlock
			anchors.top: serialNumberBlock.bottom
			anchors.topMargin: 18
			anchors.left: serialNumberBlock.left
			width: parent.width
			height: childrenRect.height
            spacing: 5

			Text
			{
				id:			textForPurchasingLicense
				objectName: "textForPurchasingLicense"
				text:		tr.Localize("TextForPurchasingLicenseWithTrial")
				width:		parent.width
				anchors.left: parent.left
				wrapMode:	Text.Wrap
				font:		activationWizard.fontStyles.masterOfActivationButtonsNormalText
				horizontalAlignment: Text.AlignLeft
			}

			Flow
			{
				id:buttonList
				objectName:	"buttonList"
				anchors.left: parent.left
				anchors.right: parent.right
                spacing: 10
				Repeater
				{
					objectName:	"buttonListRepeater"
					model: context.ActivationPageEdition.LNCSButtonList
                    Widgets.Hyperlink
					{
						id: buttonForPurchasingLicense
						function prepareText()
						{
							if(model.modelData.shouldLocalize == undefined || !model.modelData.shouldLocalize)
								return model.modelData.name;
							return tr.Localize(model.modelData.name);
						}
						text: prepareText()
                        objectName: model.modelData.objectName
						onClicked:
						{	
							var item = Common.buildPath(parent)+"."+buttonForPurchasingLicense.objectName;
							if (context.StartInProductPurchasing(model.modelData.ippLink, item, Network))
								return;

							if(model.modelData.action != undefined)
								model.modelData.action.Invoke(item);
						}
					}
				}
			}
		}
	}
	Item
	{
		objectName: "forTrialLicense"
		anchors.top: commercialActivationBlock.bottom
		anchors.topMargin: 30
		anchors.left:			parent.left
		anchors.right:			parent.right
		visible:				showTrialBlock()
		Widgets.RadioButton
		{
			id:						selectionForTrialLicense
			objectName: "selectionForTrialLicense"
			group:					selectionForActivationType
			text:					tr.Localize("SelectionTrialLicense")
			horizontalMargin:		7
			color: 					"transparent"
			checked:				EnumHelper.getKey(context.ActivationPageEdition, "LicenseType") == "LicenseTypeTrial"
			textfont:				activationWizard.fontStyles.checkBoxTextNormal
			anchors.left:			parent.left
			anchors.top:			parent.top
			textVerticalMargin: -1

			onCheckedChanged:
			{
				if (checked)
				{
					context.ActivationPageEdition.LicenseType = "LicenseTypeTrial";
					if(!context.ActivationPageEdition.isActivationCodeReadOnly)
						context.ActivationCode = "";
				}
			}
		}
		Text
		{
			id:					textForTrialLicense
			text:				tr.Localize("TextForTrialLicense")
			anchors.left:		parent.left
			anchors.leftMargin: 24
			anchors.right:		parent.right
			anchors.top:		selectionForTrialLicense.bottom
			anchors.topMargin:	6
			font:				activationWizard.fontStyles.masterOfActivationButtonsNormalText
			wrapMode:			Text.Wrap
			horizontalAlignment: Text.AlignLeft
		}
	}
}

