import QtQuick 1.1
import QtWidgetProxies 1.0
import "../fonts" as Fonts
import "../EnumHelper.js" as EnumHelper
import "../ProductTypeHelper.js" as ProductTypeHelper

SecondaryWindow
{
    property variant commonFontStyles: Fonts.Common{}
    property string iconSource
    property string description
    property string additionalDescription
    property string cancelButtonText
    property string rebootButtonText

    signal cancelClicked
    signal rebootClicked

    SystemPalette {id: activePalette}

    id: notification
    objectName:	"RebootMessageBox"

    hasFooter: false
    width: 500
    height: workAreaItem.childrenRect.height + 78

    workArea : Item
    {
        id: workArea
        objectName:	"workArea"

        Image
        {
            id: icon
            source: notification.iconSource
            anchors.left: parent.left;
            anchors.leftMargin: 20
            anchors.top: parent.top;
            anchors.topMargin: 20
        }

        Text
        {
            id: title
            anchors.left: icon.right;
            anchors.leftMargin: 20;
            anchors.top: icon.top;
            anchors.right: parent.right;
            anchors.rightMargin: 20;
            text: notification.description
            wrapMode: Text.WordWrap
            font.family: "Tahoma"
            font.pointSize: 10
            font.bold: true
            horizontalAlignment: Text.AlignLeft
        }

        Text
        {
            id: description
            anchors.left: title.left;
            anchors.top: title.bottom;
            anchors.topMargin: 5
            anchors.right: parent.right;
            anchors.rightMargin: 20;
            text: notification.additionalDescription
            wrapMode: Text.WordWrap
            horizontalAlignment: Text.AlignLeft
            font.family: "Tahoma"
            font.pointSize: 9
        }

        Row // buttons group
        {
            anchors
            {
                right: parent.right
                rightMargin: 20
                top: description.bottom
                topMargin: 20
            }

            spacing: 5
            objectName:	"buttonsGroup"

            GrayButton
            {
                id: rebootButton
                setAsDefaultButton: true
                objectName:	"RebootButton"
                text: notification.rebootButtonText
                onClicked: rebootClicked()
            }

            GrayButton
            {
                id: cancelButton
                objectName:	"CancelButton"
                text: notification.cancelButtonText
                onClicked: cancelClicked()
            }
        }
    }
}
