import QtQuick 1.1
import "../fonts" as Fonts
import "../widgets" as Widgets

Widgets.HotKeyScope
{
	id: secondaryWindow
	objectName: "secondaryWindow"

	LayoutMirroring.enabled: Window.Mirror
	LayoutMirroring.childrenInherit: true
	property variant defaultButtonManager: defaultButtonManagerId
	Widgets.DefaultButtonManager{id: defaultButtonManagerId}
	Keys.forwardTo: defaultButtonManagerId

	Keys.onEscapePressed: Window.Close();

	focus: true
    clip: true

	property string caption: ""
	property string systemCaption: caption
	property alias workArea: workAreaLoader.sourceComponent
	property alias workAreaItem: workAreaLoader.item
	property alias buttonsArea: buttonsAreaLoader.sourceComponent
    property alias buttonsAreaItem: buttonsAreaLoader.item
	property bool hasFooter: true
	property alias iconImage: icon.source
	property alias canMinimize: windowButtons.minimizeButtonEnabled
	property alias showMinimize: windowButtons.minimizeButtonVisible
	property variant commonFontStyles: Fonts.Common{}
    property alias hotKeysEnabled: secondaryWindow.hotKeysEnabled;

	signal close

	width: 300
	height: 500

	property bool dpiScaleWidth: true

	Widgets.DPIScaler { changeWidth: dpiScaleWidth }

	onSystemCaptionChanged: Window.SetCaption(systemCaption)

	Rectangle
	{
		id: rect
		anchors
		{
			fill: parent
			topMargin: 29
			leftMargin: 9
			rightMargin: 9
            bottomMargin: secondaryWindow.hasFooter ? 44 : 10
		}
		color: "white"
	}
	Loader
	{
		objectName: "workAreaLoader"
		id: workAreaLoader
		anchors.fill: rect
	}

	BorderImage
	{
		anchors.fill: parent
        source: hasFooter ? "../images/secondary/secondary_window_frame.png" : "../images/secondary/secondary_window_frame_no_footer.png"
		border
		{
			left: 100
			right: 100
			top: 100
            bottom: 100
		}
	}

	Row
	{
		anchors
		{
			verticalCenter: parent.top
			verticalCenterOffset: 15
			left: parent.left
            leftMargin: 6
		}
		spacing: 4
		Image
		{
			id: icon
			source: "../images/window/ico_k_16.png"
			anchors.verticalCenter: parent.verticalCenter
		}
		Text
		{
			id: captionText
			font: commonFontStyles.standardWindowCaptionFont
			anchors.verticalCenter: parent.verticalCenter
			anchors.verticalCenterOffset: 1
			text: secondaryWindow.caption
		}
	}

	SecondaryWindowButtons { id: windowButtons; onClose: { secondaryWindow.close(); Window.Close() } }

	Loader
	{
		id: buttonsAreaLoader
		objectName: "buttonsAreaLoader"
		anchors
		{
			left: rect.left
			right: rect.right
			top: rect.bottom
			topMargin: 7
			bottom: parent.bottom
			bottomMargin: 7
		}
	}
}
