import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/fonts" as Fonts
import "../common/EnumHelper.js" as EnumHelper
import "../common/widgets" as Widgets
import "../common/border" as Border
import "../common/Colors.js" as Colors
import "../common/DateTime.js" as DateTime

Border.BorderedContent
{
	Localizer { id:tr; scope:"LicenseManager" }
	objectName: "AdditionalLicenseInfo"
    content: page
    
    function showPage(page)	{}

    Widgets.SecondaryWindow
    {
        objectName: "AdditionalLicenseInfoDialog"
        id:page
        width:690
        function updateHeight(workingAreaHeight)
		{
			height = Math.max(280, workingAreaHeight + 150)
		}
        canMinimize:false
		caption: tr.Localize("AdditionalLicenseInformationCaption");

        property variant model : AdditionalLicenseInformation
        property variant commonFontStyles: Fonts.Common{}

        function getLicenseImage()
        {
            return EnumHelper.convert(AdditionalLicenseInformation, "ActiveLicenseState", {
                "Actual":"../common/images/license/pic_license_normal.png",
                "Invalid":"../common/images/license/pic_license_expired.png",
                "Unknown":"../common/images/license/pic_license_unknown.png",
                "HasWarnings":"../common/images/license/pic_license_normal.png"});
        }

        function getStatusColor()
        {
            return EnumHelper.convert(AdditionalLicenseInformation, "ActiveLicenseState", {
				"Actual":Colors.green,
				"Invalid":Colors.red,
				"Unknown":"gray",
				"HasWarnings":Colors.green});
        }

        workArea : Item
        {
			objectName: "workArea"
			id: workingArea
			property int childrenRectHeight: childrenRect.height
			onChildrenRectHeightChanged: page.updateHeight(childrenRectHeight)
            Image
            {
                id: licenseImage
                source: page.getLicenseImage();
                anchors.left:parent.left;anchors.leftMargin:30
                anchors.top:parent.top;anchors.topMargin:34
            }

            ListView
            {
                id:infoList
                anchors.left:licenseImage.right;anchors.leftMargin:32
                anchors.top:licenseImage.top
                anchors.topMargin: 3
                anchors.right:parent.right
                onContentHeightChanged: height = contentHeight
		        Component.onCompleted: height = contentHeight
                model:page.model.LicenseInfo
                interactive: false
                delegate:infoDelegate
                spacing:6
            }

            Component
            {
                 id: infoDelegate
                 Item
                 {
                     width:infoList.width;
                     height:commonItem.height
                     visible: true;

                     Widgets.StaticLabel
                     {
                         id:commonItem
                         
						 function prepareVariables()
						 {
							var variableMap = {
								"LicensePcCount" : page.model.licenseProperties.licensePcCount,
								"LicenseLifespan" : DateTime.localizeTimeIntervalFromDaysCount(page.model.licenseProperties.licenseLifespanInDays, tr),
								"LicenseType" : tr.Localize(page.model.licenseProperties.licenseType),
                                "LicenseExpirationDate" : tr.LocalizeDateTimeShort(page.model.licenseProperties.expirationDate),
                                "SubscriptionExpirationDateTimeWithSecond" : tr.LocalizeDateTimeShort(page.model.licenseProperties.expirationDate),
                                "SubscriptionExpirationDate" : tr.LocalizeDateTimeShort(page.model.licenseProperties.expirationDate),
                                "LicenseExpirationDateTimeWithSeconds" : tr.LocalizeDateTimeShort(page.model.licenseProperties.expirationDate),
								"LicenseRemainingDaysCount" : page.model.licenseProperties.licenseRemainingDaysCount,
                                "TicketValidFromDate" : tr.LocalizeDateTimeShort(page.model.ticketValidFromDate),
                                "TicketValidToDate" : tr.LocalizeDateTimeShort(page.model.ticketValidToDate),
                                "ActivationDate" : tr.LocalizeDateTimeShort(page.model.activationDate),
                                "InstallationDate" : tr.LocalizeDateTimeShort(page.model.installationDate)
							};
							return variableMap;
						 }
						caption: tr.Localize(model.modelData.name);
						value: model.modelData.shouldLocalize ? tr.Localize(model.modelData.value, prepareVariables()) : model.modelData.value;

                         captionFont:page.commonFontStyles.standardCommonTextFont
                         valueFont:page.commonFontStyles.standardCommonTextFont
                         valueColor:model.modelData.isLicenseState ? page.getStatusColor() : "gray";
                         isWrapMode: true;
                         wrapToBottom: true;
                     }
                 }
            }
        }
            buttonsArea : Item
        {
			objectName: "buttonsArea"
            Row
            {
                spacing: 10
                height: parent.height
                anchors.right: parent.right;
                objectName: "row"

                Widgets.GrayButton
                {
                    objectName: "AdditionalLicenseInfo_CloseButton"
                    setAsDefaultButton: true
                    text: tr.Localize("CloseButton");
                    onClicked: { Window.Close() }
                    anchors.verticalCenter: parent.verticalCenter
                    verticalMargin: 10
                    horizontalMargin: 20
                }
            }
        }
    }
}
