import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../main_window" as MainFrame

import "../common/Colors.js" as Colors
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/DateTime.js" as DateTime
import "../common/HelpMapper.js" as HelpMapper
import "../common/EnumHelper.js" as EnumHelper

MainFrame.InnerContent
{
    Localizer { id: trMainWindow; scope:"MainWindow" }
    caption: tr.Localize("TopTitle")
    objectName: "safeBankingContent"
    property int helpId: HelpMapper.SafeBankingHelpId
	property string settingsPage: "SafeBanking"

    Localizer { id: tr; scope: "SafeBanking" }
    property variant commonFontStyles: Fonts.Common{}
    property variant context: MainWindow.safeBanking

    function getLicenseState(object, licenseState)
    {
        return EnumHelper.convert(object, licenseState, {
            "Actual" : true,
            "HasWarnings" : true,
            "Invalid" : false,
            "Unknown" : false
        });
    }

    property bool validLicense: context.isFullFunctionality

    property bool selfDefenceEnabled: context.selfDefenceEnabled

    captionArea: Component
    {
        Item
        {
            objectName: "captionArea"

            Widgets.CaptionButton
            {
                id: addButton
                objectName: "addButton"
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 1
                anchors.right: parent.right
                anchors.rightMargin: 8
                minWidth: 0
                enabled: context.enabled && context.protectionEnabled && validLicense && selfDefenceEnabled
                visible: enabled
                text: tr.Localize("AddUrl")
                onClicked: {
                    context.AddUrlSettings();
                }
                mirror: Window.Mirror
            }
        }
    }

    viewArea: Component
    {
        Rectangle
        {
            id: backgroundRect

            anchors.fill: parent

            BorderImage
            {
                id: background
                anchors.fill: parent
                horizontalTileMode: BorderImage.Repeat
                verticalTileMode: BorderImage.Repeat
                source: "../common/images/main_window/background.png"
            }

            Row
            {
                id: safeBankingContentRow

                anchors.fill: parent
                anchors.leftMargin: 5

                Item
                {
                    id: descriptionPart

                    width: parent.width / 2
                    anchors.top: parent.top
                    anchors.bottom: parent.bottom

                    Column
                    {
                        id: descriptionColumn

                        anchors.fill: parent
                        anchors.topMargin: 90
                        anchors.bottomMargin: 50
                        spacing: 20

                        Item
                        {
                            id: descriptionImageItem

                            height: parent.height / 2
                            anchors.left: parent.left
                            anchors.right: parent.right

                            Image
                            {
                                id: descriptionLogoImage

                                anchors.verticalCenter: parent.verticalCenter
                                anchors.horizontalCenter: parent.horizontalCenter

                                source: "../common/images/safe_banking/safe_banking_logo.png"
                            }
                        }

                        Item
                        {
                            id: descriptionTextItem

                            height: parent.height / 2
                            anchors.left: parent.left
                            anchors.right: parent.right
                            anchors.leftMargin: 22
                            anchors.rightMargin: 20

                            Item
                            {
                                id: descriptionTextColumn
                                anchors.fill: parent
                                anchors.margins: 5

                                Text
                                {
                                    id: descriptionTitleText

                                    anchors.left: parent.left

                                    font: commonFontStyles.standardCaptionFont
                                    horizontalAlignment: Text.AlignLeft

                                    text: tr.Localize("Title")
                                    color: "#505050"
                                }

                                Text
                                {
                                    id: descriptionText

                                    anchors.top: descriptionTitleText.bottom
                                    anchors.topMargin: 6
                                    anchors.left: parent.left
                                    anchors.right: parent.right

                                    font: commonFontStyles.standardCommonTextFont
                                    horizontalAlignment: Text.AlignLeft

                                    text: tr.Localize("Description")
                                    wrapMode: Text.WordWrap
                                }

                                Widgets.Hyperlink
                                {
                                    id: learnMoreLink
									objectName: "learnMoreLink"

                                    anchors.top: descriptionText.bottom
                                    anchors.topMargin: 8
                                    anchors.left: parent.left

                                    horizontalAlignment: Text.AlignLeft

                                    text: tr.Localize("LearnMore")

                                    onClicked:
                                    {
                                        Window.OpenTemplateURL("$HelpURLSettingsOnlineBanking")
                                    }
                                }
                            }
                        }
                    }
                }

                Item
                {
                    id: bankingListPart

                    width: parent.width / 2
                    height: parent.height

                    anchors.top: parent.top
                    anchors.bottom: parent.bottom

                    Rectangle
                    {
                        id: listBackgroundRectangle
                        color: "white"
                        anchors.fill: parent
                    }

                    Rectangle
                    {
                        id: listLeftBorder

                        anchors.left: parent.left

                        height: parent.height
                        width: 1
                        color: "#E7E7E7"
                    }

                    Widgets.ScrollBar
                    {
                        id: scrollBar
                        objectName: "ScrollBar"

                        anchors.right: parent.right
                        anchors.top: parent.top
                        anchors.bottom: parent.bottom

                        target: urlSettingsList
                    }

                    ListView
                    {
                        id: urlSettingsList

                        anchors.left: parent.left
                        anchors.right: scrollBar.left
                        anchors.top: parent.top
                        height: parent.height

                        visible: context.urlSettings.length !== 0 && context.enabled && context.protectionEnabled && validLicense && selfDefenceEnabled

                        model: context.urlSettings
                        clip: visible

                        onVisibleChanged: returnToBounds()

                        delegate: Item
                        {
                            id: urlSettingsItem

                            anchors.left: parent.left
                            anchors.right: parent.right
                            property bool showControls: mouseArea.containsMouse || deleteButton.state == 'hover'
                                || editButton.state == 'hover' || urlLink.hovered

                            height: 65

                            function editUrl()
                            {
                                context.ModifyUrlSettings(index);
                            }

                            function deleteUrl()
                            {
                                context.RemoveUrlSettings(index);
                            }

                            MouseArea
                            {
                                id: mouseArea
                                anchors.fill: parent
                                hoverEnabled: true
                            }

                            Rectangle
                            {
                                id: separator
                                height: 1
                                width: parent.width
                                anchors.bottom: parent.bottom
                                color: '#e7e7e7'
                            }

                            Item
                            {
                                id: imageItem
                                anchors.left: parent.left
                                anchors.top: parent.top
                                anchors.bottom: parent.bottom
                                anchors.leftMargin: 15
                                anchors.rightMargin: 5

                                width: 24

                                Image
                                {
                                    id: defaultImage
                                    anchors.verticalCenter: parent.verticalCenter
                                    anchors.horizontalCenter: parent.horizontalCenter
                                    height: 16
                                    width: 16

                                    source: "../common/images/safe_banking/safe_banking_default_bank_logo.png"

                                    visible: !modelData.hasFavicon && !modelData.isIconLoading
                                }

                                RawImage
                                {
                                    id: faviconImage

                                    anchors.horizontalCenter: parent.horizontalCenter
                                    anchors.verticalCenter: parent.verticalCenter
                                    image: modelData.faviconImage

                                    height: 16
                                    width: 16

                                    visible: modelData.hasFavicon && !modelData.isIconLoading
                                }

                                Widgets.Loading16
                                {
                                    id: progress
                                    anchors.horizontalCenter: parent.horizontalCenter
                                    anchors.verticalCenter: parent.verticalCenter

                                    running: modelData.isIconLoading
                                    visible: modelData.isIconLoading
                                }
                            }

                            Item
                            {
                                id: urlItem

                                anchors.verticalCenter: parent.verticalCenter
                                anchors.left: imageItem.right
                                anchors.leftMargin: 12
                                anchors.right: editButtonWrapper.left

                                height: childrenRect.height

                                clip: true

                                Widgets.Hyperlink
                                {
                                    id: 	urlLink
                                    objectName: "urlLink"
                                    anchors.left: parent.left
                                    anchors.top: parent.top

                                    font: commonFontStyles.standardHyperlinkFont
                                    horizontalAlignment: Text.AlignLeft
                                    elide: Text.ElideRight
                                    text:	modelData.title

                                    onClicked:
                                    {
                                        context.LaunchSafeBrowser(modelData)
                                    }
                                }

                                Text
                                {
                                    id: urlHost
                                    objectName: "urlHost"

                                    anchors.left: parent.left
                                    anchors.right: parent.right
                                    anchors.top: urlLink.bottom
                                    anchors.topMargin: 4

                                    font: commonFontStyles.standardSubHeaderFont

                                    horizontalAlignment: Text.AlignLeft
                                    elide: Text.ElideRight
                                    text: modelData.host
                                }
                            }

                            BorderImage
                            {
                                source: "../common/images/safe_banking/right_border.png"
                                height: parent.height - 1
                                width: sourceSize.width
                                anchors.right: editButtonWrapper.right
                                visible: urlLink.width > urlItem.width
                            }

                            Image
                            {
                                id: editButtonWrapper
                                objectName: "EditButtonWrapper"

                                source: "../common/images/safe_banking/safe_banking_edit.png"
                                anchors.right: deleteButtonWrapper.left
                                anchors.rightMargin: 7
                                anchors.verticalCenter: parent.verticalCenter
                                anchors.verticalCenterOffset: -9
                                //visible: urlSettingsItem.showControls
                                opacity: editButton.state === 'hover' ? 0.8 : 1

                                width: 16
                                height: 16

                                Widgets.BaseButton
                                {
                                    id: editButton
                                    objectName: "safeBankingEditButton"
                                    anchors.fill: parent

                                    onClicked: editUrl();
                                }
                            }

                            Image
                            {
                                id: deleteButtonWrapper
                                objectName: "DeleteButtonWrapper"

                                source: "../common/images/safe_banking/safe_banking_delete.png"
                                anchors.right: parent.right
                                anchors.rightMargin: 11
                                anchors.verticalCenter: parent.verticalCenter
                                anchors.verticalCenterOffset: editButtonWrapper.anchors.verticalCenterOffset
                                //visible: urlSettingsItem.showControls
                                opacity: deleteButton.state === 'hover' ? 0.8 : 1

                                width: 16
                                height: 16

                                Widgets.BaseButton
                                {
                                    id: deleteButton
                                    objectName: "safeBankingEditButton"
                                    anchors.fill: parent

                                    onClicked: deleteUrl();
                                }
                            }

                            Widgets.DPIScaler {changeHeight: true}
                        }
                    }

                    Item
                    {
                        id: emptyListAddItem

                        height: childrenRect.height
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: 5

                        width: parent.width * 3 / 4
                        visible: context.urlSettings.length === 0 && context.enabled && context.protectionEnabled && validLicense && selfDefenceEnabled

                        Text
                        {
                            id: addText

                            anchors.left: parent.left
                            anchors.right: parent.right

                            horizontalAlignment: Text.AlignHCenter

                            color: "#adadad"
                            font: commonFontStyles.standardBoldSubHeadingFont

                            text: tr.Localize("EmptyListText")

                            wrapMode: Text.WordWrap
                        }

                        Widgets.GrayButton
                        {
                            id: addButton
                            objectName: "AddButton"

                            anchors.top: addText.bottom
                            anchors.topMargin: 10
                            anchors.horizontalCenter: parent.horizontalCenter

                            text: tr.Localize("Add")

                            onClicked:
                            {
                                context.AddUrlSettings();
                            }
                        }
                    }

                    Item
                    {
                        id: safeBankingSelfDefenceDisabledItem

                        height: childrenRect.height
                        anchors.left: parent.left
                        anchors.right: parent.right
                        anchors.leftMargin: 15
                        anchors.rightMargin: 15
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: 5

                        width: parent.width / 2
                        visible: !selfDefenceEnabled

                        Text
                        {
                            id: selfDefenceDisabledText
                            objectName: "SelfDefenceDisabledText"

                            anchors.left: parent.left
                            anchors.right: parent.right

                            horizontalAlignment: Text.AlignHCenter

                            color: "#adadad"
                            font: commonFontStyles.standardBoldSubHeadingFont

                            text: tr.Localize("SelfDefenceDisableWarningText")

                            wrapMode: Text.WordWrap
                        }

                        Widgets.GrayButton
                        {
                            id: enableSelfDefenceButton
                            objectName: "SelfDefenceEnableButton"

                            anchors.top: selfDefenceDisabledText.bottom
                            anchors.topMargin: 10
                            anchors.horizontalCenter: parent.horizontalCenter

                            text: tr.Localize("EnableSelfDefence")

                            onClicked:
                            {
                                context.EnableSelfDefence();
                            }
                        }
                    }

                    Item
                    {
                        id: safeBankingDisabledItem

                        height: childrenRect.height
                        anchors.left: parent.left
                        anchors.right: parent.right
                        anchors.leftMargin: 15
                        anchors.rightMargin: 15
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: 5

                        width: parent.width / 2
                        visible: (!context.enabled || !context.protectionEnabled) && validLicense && selfDefenceEnabled

                        Text
                        {
                            id: disableText

                            anchors.left: parent.left
                            anchors.right: parent.right

                            horizontalAlignment: Text.AlignHCenter

                            color: "#adadad"
                            font: commonFontStyles.standardBoldSubHeadingFont

                            text: tr.Localize("DisableWarningText")

                            wrapMode: Text.WordWrap
                        }

                        Widgets.GrayButton
                        {
                            id: enableButton
                            objectName: "EnableButton"

                            anchors.top: disableText.bottom
                            anchors.topMargin: 10
                            anchors.horizontalCenter: parent.horizontalCenter

                            text: tr.Localize("Enable")

                            onClicked:
                            {
                                context.EnableSafeBanking()
                            }
                        }
                    }

                    Item
                    {
                        id: safeBankingInvalidLicenseItem

                        height: childrenRect.height
                        anchors.left: parent.left
                        anchors.right: parent.right
                        anchors.leftMargin: 15
                        anchors.rightMargin: 15
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: 5

                        visible: !validLicense && selfDefenceEnabled

                        Text
                        {
                            id: invalidLicenseTitle

                            anchors.left: parent.left
                            anchors.right: parent.right

                            horizontalAlignment: Text.AlignHCenter

                            color: "#adadad"
                            font: commonFontStyles.standardBoldSubHeadingFont

                            text: tr.Localize("DisableWarningText")

                            wrapMode: Text.WordWrap
                        }

                        Text
                        {
                            id: invalidLicenseText

                            anchors.top: invalidLicenseTitle.bottom
                            anchors.topMargin: 5
                            anchors.left: parent.left
                            anchors.right: parent.right

                            horizontalAlignment: Text.AlignHCenter

                            color: "#adadad"
                            font: commonFontStyles.standardCommonTextFont

                            text: tr.Localize("LicenseWarningText")

                            wrapMode: Text.WordWrap
                        }

                        Widgets.GrayButton
                        {
                            id: goToLicenseInformationButton
                            objectName: "EnableButton"

                            anchors.top: invalidLicenseText.bottom
                            anchors.topMargin: 10
                            anchors.horizontalCenter: parent.horizontalCenter

                            text: tr.Localize("LicenseInformation")

                            onClicked:
                            {
                                MainWindow.ShowLicenseManagerAction.Invoke();
                            }
                        }
                    }
                }
            }
        }
    }
}

