import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../main_window" as MainFrame
import "../common/HelpMapper.js" as HelpMapper
import "../common/Common.js" as Common
import "../common/Stat.js" as Stat

MainFrame.InnerContent
{
    id: scanPanel
    objectName: "ScanPanel"
    Localizer { id:trMainWindow; scope:"MainWindow" }
    Localizer { id:tr; scope:"ScanTask" }
	caption: trMainWindow.Localize("Scan")
    property int helpId: HelpMapper.ScanHelpId
    property string settingsPage: "ScanGeneral"

	captionArea: Component
	{
		Item 
		{
			clip:           false
			property variant context: MainWindow.Scan
			objectName:	"captionArea"

			Widgets.CaptionButton
			{
				Localizer { id:trScan; scope:"Scan" }
				id: 		taskManager
				objectName:	"taskManagerButton"
				text:		trScan.Localize("TaskManager")
				onClicked:	context.ShowShowTaskManager.InvokeAsync()
            }
		}
	}

	viewArea: Component
	{
		Item
		{
			property variant context: MainWindow.Scan
			property variant commonFontStyles: Fonts.Common{}

			id: 		scanPanel
			objectName:	"ScanPanel"
			anchors.fill: parent
			clip:		false

            Widgets.DPIScaler { id: scaler }
            property int itemWidth:		338 * scaler.factor
            property int itemHeight:	167 * scaler.factor
            property int leftMargin: 17 * scaler.factor
            property int rightMargin: 18 * scaler.factor
            property int topMargin: 23 * scaler.factor

            BorderImage
            {
                id: background
                anchors.fill: parent
                horizontalTileMode: BorderImage.Repeat
                verticalTileMode: BorderImage.Repeat
                source: "../common/images/main_window/background.png"
            }

			ScanTask
			{
				id: fullScanTask
				objectName:		"FullScan"
				width:			scanPanel.itemWidth
				height:			scanPanel.itemHeight
				anchors.top: parent.top
				anchors.topMargin: scanPanel.topMargin
				anchors.left: parent.left
				anchors.leftMargin: scanPanel.leftMargin
				context:		MainWindow.Scan
				contextScan: context.FullScan;

				scanHeader:		tr.Localize("FullScan_Title")
				firstTimeRun:	tr.Localize("FullScan_Description")
				askStopScan:	tr.Localize("FullScan_StopConfirmation")
				askResumeScan:	tr.Localize("FullScan_ResumeConfirmation")

				Keys.onRightPressed: criticalAreaScanTask.forceActiveFocus()
				Keys.onDownPressed: vulnerabilityScanTask.forceActiveFocus()
			}

			ScanTask
			{
                id: criticalAreaScanTask
				objectName:		"CriticalAreaScan"
				width:			scanPanel.itemWidth
				height:			scanPanel.itemHeight
                anchors.top: parent.top
                anchors.topMargin: scanPanel.topMargin
                anchors.right: parent.right
                anchors.rightMargin: scanPanel.rightMargin
				context:		parent.context
				contextScan:	context.CriticalAreaScan

				scanHeader:		tr.Localize("CriticalAreaScan_Title")
				firstTimeRun:	tr.Localize("CriticalAreaScan_Description")
				askStopScan:	tr.Localize("CriticalAreaScan_StopConfirmation")
				askResumeScan:	tr.Localize("CriticalAreaScan_ResumeConfirmation")

				Keys.onLeftPressed: fullScanTask.forceActiveFocus()
				Keys.onDownPressed: dragAndDropScan.forceActiveFocus()
			}
			ScanTask
			{
                id: vulnerabilityScanTask
				objectName:		"VulnerabilityScan"
				width:			scanPanel.itemWidth
				height:			scanPanel.itemHeight
                anchors.left: parent.left
                anchors.leftMargin: scanPanel.leftMargin
				anchors.top: fullScanTask.bottom
                anchors.topMargin: scanPanel.topMargin - 5 * scaler.factor
				context:		parent.context
				contextScan: 	context.VulnerabilityScan

				scanHeader:		tr.Localize("VulnerabilityScan_Title")
				firstTimeRun:	tr.Localize("VulnerabilityScan_Description")
				askStopScan:	tr.Localize("VulnerabilityScan_StopConfirmation")
	
				Keys.onRightPressed: dragAndDropScan.forceActiveFocus()
				Keys.onUpPressed: fullScanTask.forceActiveFocus()
			}

			Rectangle // Drag&Drop
			{
				objectName: "DragAndDropScan"
				id: dragAndDropScan
				width: scanPanel.itemWidth
				height: scanPanel.itemHeight
				color: "transparent"
				property variant context: scanPanel.context
                anchors.top: vulnerabilityScanTask.top
                anchors.left: criticalAreaScanTask.left
				property int tabOrder: vulnerabilityScanTask.tabOrder
                Widgets.FocusRect
                {
                	anchors.leftMargin: -3
                    anchors.rightMargin: -5
                }

				FileDropArea
				{
					anchors.fill: parent
					onDropped:
					{
						context.StartScanTask(fileList)
                        Stat.onButtonClick(Common.buildDelegatelessPath(dragAndDropScan));
					}
                }

                BorderImage
                {
                    id: dragAndDrop
					objectName: "dragAndDrop"
                    width: scanPanel.itemWidth
                    height: scanPanel.itemHeight
                    border{left:5; right:5; top: 5; bottom:5}
                    horizontalTileMode: BorderImage.Repeat
                    verticalTileMode: BorderImage.Repeat
                    source: "../common/images/scan/scan_task_background.png"

                    Image
                    {
                        id: dragAndDropImage
                        objectName: "DragAndDropArea"
                        anchors.top: parent.top
                        anchors.topMargin: 27
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.horizontalCenterOffset: 20
                        source: "../common/images/scan/scaner.png"
                        Widgets.DPIScaler { changeSize: true }
                    }

                    Text
                    {
                        id: dropAreaText
                        anchors.top: dragAndDropImage.bottom
                        anchors.topMargin: 6
                        anchors.horizontalCenter: parent.horizontalCenter
                        horizontalAlignment: Text.AlignHCenter
                        objectName: "ScanLinkArea"
                        width: parent.width - 60
                        color: "black"
                        font: commonFontStyles.standardCommonTextFont
                        wrapMode: Text.WordWrap
                        textFormat: Text.RichText
                        text: tr.Localize("CustomAreaScan_Description")
                    }

                    MouseArea
                    {
                        anchors.fill: parent
                        onClicked:
						{
                            Stat.onButtonClick(Common.buildDelegatelessPath(dragAndDrop));
							context.ShowCustomScanSelectObjects.Invoke();							
						}
                        hoverEnabled: true
                        Widgets.Clickable {}
                        onPressed:
                        {
                            if (!dragAndDropScan.activeFocus)
                                dragAndDropScan.forceActiveFocus();
                        }
                    }
                }

				Keys.onLeftPressed: vulnerabilityScanTask.forceActiveFocus()
				Keys.onUpPressed: criticalAreaScanTask.forceActiveFocus()
			}
		}
	}
}
