import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/fonts" as Fonts
import "../common/widgets" as Widgets
import "../common/border" as Border
import "../common/EnumHelper.js" as EnumHelper
import "../common/ProductTypeHelper.js" as ProductTypeHelper

Border.BorderedContent
{
	content: installFinished
	objectName: "rebootPage"
	Localizer { id:tr; scope:"RebootPage" }
	
	Widgets.PageFrame
	{
		id:	installFinished
		objectName: "installFinished"
		property variant context: RebootPage
		property variant fontStyles: Fonts.Common{}

		LayoutMirroring.enabled: Window.Mirror
		LayoutMirroring.childrenInherit: true

		property variant defaultButtonManager: defaultButtonManagerId
		Widgets.DefaultButtonManager{id: defaultButtonManagerId}
		Keys.forwardTo: defaultButtonManagerId
		focus: true

		Keys.onEscapePressed: Window.Close();

		windowDescriptionText: tr.Localize("RebootPageHeader", {"ProductName":ProductTypeHelper.getProductName(tr, context)})
		helpButtonVisible: false
		cancelButtonText: tr.Localize("FinishButton")
		cancelButtonIsDefault: true
		onCancel: finish()
		signal finish
		clip: true

		Item
		{
			id: workingArea
			objectName: "workingArea"
			anchors.fill: parent
			clip: true
			
			anchors.topMargin: 29
			anchors.leftMargin: 164 /* banner width */  + 10 /*left border*/
			anchors.bottomMargin: 43
			anchors.rightMargin: 10

			Column
			{
				anchors.fill: parent
				anchors.topMargin:		40
				anchors.leftMargin:		40
				anchors.rightMargin:	40
				spacing:		40
				clip: true
				objectName: "column"

				Widgets.StandardCaptionText
				{
					id: headerText
					anchors.left: parent.left
					anchors.right: parent.right
					text: tr.Localize("RebootPageHeaderText")
				}

				Text
				{
					id: infoText
					anchors.left: parent.left
					anchors.right: parent.right
					text: tr.Localize("RebootPageInfoText", {"ProductName":ProductTypeHelper.getProductName(tr, installFinished.context)})
					wrapMode: Text.Wrap
					font: installFinished.fontStyles.standardCommonTextFont
				}

				Widgets.CheckBox
				{
					id: rebootCheckbox
					anchors.left: parent.left
					objectName: "rebootCheckbox"
					checked: true
					text: tr.Localize("RebootPageCheckboxRebootText")
				}
			}
		}

		onFinish:
		{
			if (rebootCheckbox.checked)
				context.Reboot();
			else
				context.Cancel();
			Window.Close();
		}

		onClose:
		{
			context.Cancel();
			Window.Close();
		}
	}
}
