import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/border" as Border
import "../common/fonts" as Fonts
import "SupportMargins.js" as Margins


Column
{
    id: supportMonitoring
    objectName: "supportMonitoring"

    signal main
    signal sendReport
    
	property variant context: SupportWindow

    property variant commonFontStyles: Fonts.Common{}
    Localizer { id: tr; scope: "Support" }

    Widgets.DPIScaler { changeHeight: true }

    SupportPanel
    {
        objectName: "supportMonitoringPanel"
        canHome: false;
        caption: tr.Localize("MonitoringTitle")
        onBack:
        {
            supportMonitoring.main()
        }
    }

    Rectangle
    {
        height: 250
        width: parent.width
        color: "white"

        Widgets.DPIScaler { changeHeight: true }

        Column
        {
            anchors.fill: parent
            anchors.leftMargin: Margins.leftMargin
            anchors.rightMargin: 45
            anchors.topMargin: 22
            spacing: 25

            Widgets.DPIScaler { changeHeight: true }

            Text
            {
                width: parent.width
                font: commonFontStyles.standardCommonTextFont
                text: tr.Localize("MonitoringCommentFull")
                wrapMode: Text.WordWrap
            }

            Row
            {
                id: recordControl
                objectName: "RecordControl"
                width: parent.width

                spacing: 5

                Widgets.DPIScaler { changeSize: true }

                Image
                {
                    id: recordIndicator
                    source: context.tracesEnabled ? "../common/images/support/light_ready_16.png" : "../common/images/support/light_off_16.png"
                }

                Item
                {
                    objectName: "RecordControlSet"
                    width: 400
                    height: childrenRect.height

                    Widgets.DPIScaler { changeHeight: true }

                    Row
                    {
                        id: recordControlState
                        spacing: 5
                        anchors.top: parent.top
                        anchors.topMargin: recordIndicator.height / 8
                        width: parent.width

                        Widgets.DPIScaler { changeSize: true }

                        Text
                        {
                            font: commonFontStyles.standardCommonTextFontBold
                            text: tr.Localize("EventRecording")
                        }

                        Text
                        {
                            font: commonFontStyles.standardCommonTextFontBold
                            color: "#828282"
                            text: context.tracesEnabled ? tr.Localize("TracesEnabled") : tr.Localize("TracesDisabled")
                        }
                    }

                    Item
                    {
                        id: recordControlCommentSelectWrapper
                        objectName: "RecordControlCommentSelectWrapper"

                        anchors.top: recordControlState.bottom
                        anchors.topMargin: 10
                        height: childrenRect.height
                        width: 400

                        Widgets.DPIScaler { changeSize: true }

                        Text
                        {
                            id: recordControlComment
                            anchors.top: parent.top

                            opacity: context.tracesEnabled ? 0 : 1

                            width: parent.width
                            font: commonFontStyles.standardCommonTextFont
                            text: tr.Localize("EventRecordingComment")
                            wrapMode: Text.WordWrap
                            Widgets.ClickableForLinksInText
                            {
                                onLinkActivated: context.sendReport.ShowDataAgreement();
                            }
                        }

                        Item
                        {
                            id: recordControlSelect
                            objectName: "RecordControlSelect"

                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.topMargin: 5

                            height: childrenRect.height
                            opacity: context.tracesEnabled ? 1 : 0

                            Widgets.DPIScaler { changeSize: true }

                            Text
                            {
                                id: recordControlSelectText
                                anchors.left: parent.left

                                font: commonFontStyles.standardCommonTextFont
                                text: tr.Localize("TraceEvents")
                            }

                            Widgets.EnumCombo
                            {
                                id: recordControlSelectCombo
                                objectName: "RecordControlSelectCombo"

                                anchors.left: recordControlSelectText.right
                                anchors.leftMargin: 5
                                anchors.verticalCenter: recordControlSelectText.verticalCenter

                                target: context
                                property: "tracesLevel"
                                localizationObject: tr
                            }
                        }
                    }

                    Widgets.GrayButton
                    {
                        id: recordControlButton
                        objectName: "RecordControlButton"
                        anchors.top: recordControlCommentSelectWrapper.bottom
                        anchors.topMargin: 10
                        anchors.left: parent.left

                        text: context.tracesEnabled ? tr.Localize("TurnTracesDisabled") : tr.Localize("TurnTracesEnabled")

                        Widgets.DPIScaler { changeSize: true }

                        onClicked:
                        {
                            context.SwitchTracer();
                        }

                    }

                    Widgets.GrayButton
                    {
                        id: sendReportButton
                        objectName: "SendReportButton"
                        anchors.top: recordControlButton.bottom
                        anchors.topMargin: 10

                        text: tr.Localize("SendReport")

                        Widgets.DPIScaler { changeHeight: true }

                        onClicked:
                        {
                            //context.OpenSendTroublesDialog();
                            sendReport();
                        }
                    }
                }
            }
        }

    }

    Rectangle
    {
        width: parent.width
        height: 1
        color: "#CCCCCC"
    }

    Rectangle
    {
        objectName: "supportReportButtons"

        height: 272
        width: parent.width
        color: "white"

        Widgets.DPIScaler { changeHeight: true }

        Item
        {
            objectName: "supportReportButtonsWrapper"

            anchors.fill: parent
            anchors.topMargin: 25
            anchors.leftMargin: Margins.leftMargin
            width: childrenRect.width
            height: childrenRect.height

            Column
            {
                id: buttonColumn
                objectName: "ButtonColumn"

                anchors.left: parent.left
                width: childrenRect.width
                spacing: 10
                Component.onCompleted:
                {
                    applyRecommendationsButton.width = createReportButton.width = Math.max(createReportButton.width, applyRecommendationsButton.width)
                }

                Widgets.GrayButton
                {
                    id: createReportButton
                    objectName: "CreateReportButton"

                    text: tr.Localize("CreateReport")

                    Widgets.DPIScaler { changeHeight: true }

                    onClicked:
                    {
                        context.RunAvzWizard();
                    }
                }

                Widgets.GrayButton
                {
                    id: applyRecommendationsButton
                    objectName: "applyRecommendationsButton"

                    text: tr.Localize("ApplyRecommendations")

                    Widgets.DPIScaler { changeHeight: true }

                    onClicked:
                    {
                        context.RunAvzScript();
                    }
                }

                Widgets.DPIScaler { changeHeight: true }
            }

            Widgets.Hyperlink
            {
                objectName: "OpenReportLink"

                anchors
                {
                    left: buttonColumn.right
                    leftMargin: 10
                    top: parent.top
                    topMargin: createReportButton.height/4
                }

                text: tr.Localize("OpenReport")
                //color: "#5495DF"

                enabled: context.hasAvzReportFolder

                onClicked:
                {
                    context.OpenAvzReportFolder();
                }

                Widgets.DPIScaler { changeSize: true }
            }

            Widgets.DPIScaler { changeHeight: true }
        }
    }
}

