import QtQuick 1.1
import "../common/widgets" as Widgets
import "../common/Colors.js" as Colors
import "../common/EnumHelper.js" as EnumHelper

Rectangle
{
	id: frontView
	objectName: "frontView"
	width:	parent.width
	height: childrenRect.height
	color: "transparent"
	border.color: Colors.grayBorder

	signal flip

	Widgets.KeyNavigation
	{
		id: keyNavigations
		focusedItems: { return [description, progress, vulnerabilitiesList] }
	}
	Keys.onUpPressed: keyNavigations.onSetPrevious(event)
	Keys.onDownPressed: keyNavigations.onSetNext(event)

	Component.onCompleted: setActiveFocus()

	function setActiveFocus()
	{
		description.focus = true
	}

	Column
	{
        objectName: "taskItemElements"
		width: 	parent.width - 50
		anchors.horizontalCenter: parent.horizontalCenter
		Item { width: 1; height: 22 }
        TaskItemTitleLine {}
		Item { width: 1; height: 6 }
		Loader
		{
			id: description
			objectName: "description"
			width: parent.width
			source: Qt.resolvedUrl(taskModel.IsFailed ? "TaskItemFailedDescription.qml" : "TaskItemScanDescription.qml")
		}
		Widgets.ConditionalLoader
		{
			id: progress
			objectName: "progress"
			width: parent.width
			when: taskModel.IsRunning && !taskModel.IsStopping
			onFocusChanged: item.focus = focus
			conditionSource: Qt.resolvedUrl("TaskItemProgress.qml")
			Connections
			{
				target: progress.item
				onFlip: frontView.flip()
			}
		}
		Widgets.ConditionalLoader
		{
			id: vulnerabilitiesList
			objectName: "vulnerabilitiesListLoader"
			width: parent.width
			when: taskModel && EnumHelper.getKey(taskModel, "Type") == "Vulnerability" && !taskModel.IsRunning && !taskModel.IsFailed;
			conditionSource: Qt.resolvedUrl("TaskItemVulnerabilities.qml")
		}
		Item { width: 1; height: 23 }
	}
}
