import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/border" as Border
import "../../common/ProductTypeHelper.js" as ProductTypeHelper
import "../../common/HelpMapper.js" as HelpMapper
import "../../common/EnumHelper.js" as EnumHelper

Border.BorderedContent
{
    id: rescueDiskMain
    content: wizard
    property variant context: RescueDiskWizard
    property string currentPageName: context.currentPageName

    function getMarker()
    {
        return EnumHelper.getKey(context, "CurrentStateID");
    }


    Widgets.SecondaryWindow
	{
        id: wizard
        objectName: "wizard"
        width: 568
        height: 457
        Localizer { id:tr; scope:"RescueDiskWizard" }
        caption: tr.Localize("RescueDiskWizard_Caption");

        showMinimize: true
        canMinimize: true

        property int helpId : HelpMapper.RescueDiskWizardIntroHelp

        onClose:
        {
            context.OnCancelBtnPressed();
        }


        workArea: Item
		{
			objectName: "WorkArea"
			property int tabOrder: 1
            anchors.fill: parent
            Loader
            {
                id: rescuediskLoader
                objectName: "Loader"

                anchors.fill: parent

                source: currentPageName === "" ? "" : currentPageName + "/RescueDiskPage.qml"
            }
		}
		buttonsArea: FocusScope
		{
			id: bottomRow
			anchors.fill: parent
			objectName: "bottom"
			property int tabOrder: 2
            property int helpId: wizard.helpId
			Row
			{
				objectName: "links"
				property int tabOrder: 1
				anchors
				{
					verticalCenter: parent.verticalCenter
					left: parent.left
					leftMargin: 12
				}
				spacing: 12
				Widgets.HelpButton
				{
					objectName: "help"
					text: tr.Localize("Help")
					onClicked: Help.Show(bottomRow.helpId)
				}
            }
			Row
			{
				objectName: "buttons"
				property int tabOrder: 2
				anchors
				{
					verticalCenter: parent.verticalCenter
					right: parent.right
				}
				spacing: 5
				Widgets.GrayButton
				{
					setAsDefaultButton: true
                    objectName: "back"
					minWidth: applyButton.width
                    text: tr.Localize("BackButton")
                    visible: context.prevIsVisible
                    enabled: context.prevIsEnabled
				}
				Widgets.GrayButton
				{
                    objectName: "next"
					minWidth: applyButton.width
                    text: tr.Localize("NextButton")
                    visible: context.nextIsVisible
                    enabled: context.nextIsEnabled
                    onClicked:
                    {
                         context.OnNextButtonPressed()
                    }
				}
                Widgets.GrayButton
                {
                    id: applyButton
                    objectName: "cancel"
                    minWidth:85
                    text: tr.Localize("CancelButton")
                    visible: context.cancelIsVisible
                    enabled: context.cancelIsEnabled
                    onClicked:
                    {
                      if (context.canExit)
                      {
                             Window.Close();
                      }
                      else
                      {
                             context.OnCancelBtnPressed();
                      }
                    }
                }

                Widgets.GrayButton
                {
                    id: finishButton
                    objectName: "finish"
                    minWidth:85
                    text: tr.Localize("FinishButton")
                    visible: context.isFinishButton
                    enabled: true
                    onClicked:
                    {
                          Window.Close();
                    }
                }
			}
		}
		Binding
		{
            target: wizard.buttonsAreaItem
			property: "helpId"
            value: wizard.workAreaItem.helpId
            when: !!wizard.buttonsAreaItem && !!wizard.workAreaItem
		}
		Widgets.DPIScaler {
			id: dpiScaler
			changeHeight: true
		}
	}
}
