import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "SystemWatcher"

    property string helpUrl: "$HelpURLSettingsSW2"
    property int helpId: HelpMapper.SystemWatcherSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "SystemWatcher")
    property variant fontStyles: Fonts.Common{}

    Localizer { id: tr; scope: "SystemWatcherSettings" }

    Column
    {
        objectName: "MainWrapper"

        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "DescriptionSection"

            body: Column
            {
                objectName: "DescriptionSectionColumn"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                }

                SettingsCommon.CheckBox
                {
                    id: useSystemWatcher
                    anchors.left: parent.left
                    objectName: "UseSystemWatcher"
                    text: tr.Localize("UseSystemWatcher");
                    isBold: true
                    target: context
                    property: "enableSystemWatcher"
                }
            }
        }

        Item
        {
            objectName: "Row"
            height: childrenRect.height
            width: parent.width
            enabled: context.enableSystemWatcher

            SettingsCommon.CheckBox
            {
                id: automaticExploitPrevention
                objectName: "AutomaticExploitPrevention"
                text: tr.Localize("AutomaticExploitPrevention")
                isBold: true
                target: context
                property: "automaticExploitPrevention"
                maxWidth: 1000000
                anchors.left: parent.left
                anchors.verticalCenter: aEPSettings.verticalCenter
                enabled: parent.enabled
                height: aEPSettings.height
            }

            Widgets.InfoLink {
                id: helpSystemWatcher
                objectName: "HelpSystemWatcher"
                url: "$HelpURLSettingsSW2_AEP"
                height: aEPSettings.height
                anchors.left: automaticExploitPrevention.right
                anchors.leftMargin: -2
                anchors.verticalCenter: aEPSettings.verticalCenter
                enabled: parent.enabled
            }

            SettingsCommon.SettingsButton
            {
                id: aEPSettings
                objectName:"AEPSettings"
                text: tr.Localize("SettingsMore")
                anchors.left: helpSystemWatcher.right
                anchors.leftMargin: 10
                enabled: parent.enabled && context.automaticExploitPrevention
                onClicked: context.OpenAutomaticExploitPreventionSettings()              
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "HeuristicAnalysisSection"
            enabled: context.enableSystemWatcher
            name: tr.Localize("HeuristicAnalysisSection")
            body: Column
            {
                objectName: "HeuristicAnalysis"
                enabled: parent.enabled
                width: parent.width
                spacing: Margins.settingsInnerSpacing

                SettingsCommon.CheckBox
                {
                    objectName: "UseBSS"
                    text: tr.Localize("UseBSS")
                    isBold: true
                    target: context
                    property: "useBss"
                    anchors.left: parent.left
                }

                Column
                {
                    id: radioMalware
                    objectName: "RadioMalware"
                    spacing: Margins.settingsRadioSpacing
                    width: parent.width

                    SettingsCommon.SettingsStandardText
                    {
                        text: tr.Localize("OnDetectingMalwareActivity")
                        color: parent.enabled && context.useBss ? "black" : "grey"
                        anchors.left: parent.left
                    }

                    Item
                    {
                        id: isAutoHeuristicActionWrapper
                        objectName: "IsAutoHeuristicActionWrapper"
                        height: isAutoHeuristicAction.height
                        width: parent.width

                        SettingsCommon.BoolRadioGroup
                        {
                            id: isAutoHeuristicAction
                            objectName: "IsAutoHeuristicAction"
                            target: context
                            enabled: parent.enabled && context.useBss
                            property: "isAutoHeuristicAction"
                            trueDescription: context.interactionDisabled? tr.Localize("ActionAuto") : tr.Localize("ActionAsk");
                            falseDescription: tr.Localize("ActionSelect")
                            trueFirst: true
                            anchors.left: parent.left
                        }

                        SettingsCommon.EnumCombo
                        {
                            property Item lastRadio: isAutoHeuristicAction.getRadio(2)

                            objectName: "SelectedHeuristicActions"
                            anchors.left: parent.left
                            anchors.leftMargin: lastRadio.width
                            y: lastRadio.y - 2
                            enabled: parent.enabled && !context.isAutoHeuristicAction && context.useBss
                            target: context
                            property: "selectedHeuristicAction"
                            localizationObject: tr
                        }
                    }
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "RollbackOfMalwareActionsSection"
            enabled: context.enableSystemWatcher
            name: tr.Localize("RollbackOfMalwareActionsSection")
            body: Column
            {
                enabled: parent.enabled
                objectName: "Column"
                spacing: Margins.settingsSectionInnerSpacing
                width: parent.width

                Item
                {
                    objectName: "Row"
                    width: parent.width
                    height: rollbackHistorySizeSpin.height

                    enabled: parent.enabled

                    SettingsCommon.CheckBox
                    {
                        id: limitRollbackHistory
                        objectName: "LimitRollbackHistory"
                        height: rollbackHistorySizeSpin.height
                        anchors.left: parent.left
                        target: context
                        property: "limitRollbackHistory"
                        text: tr.Localize("RollbackVolumeLimit")
                        isBold: true
                        maxWidth: 1000000
                    }

                    Widgets.IntSpinEdit
                    {
                        id: rollbackHistorySizeSpin
                        objectName: "RollbackHistorySizeSpin"
                        enabled: parent.enabled && context.limitRollbackHistory
                        target: context
                        property: "rollbackHistorySize"

                        anchors.left: limitRollbackHistory.right
                        anchors.leftMargin: Margins.settingsBeforeSpinEdit
                        anchors.verticalCenter: limitRollbackHistory.verticalCenter
                        anchors.verticalCenterOffset: 2

                        minValue: 20
                        maxValue: 4000
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        anchors.left: rollbackHistorySizeSpin.right
                        anchors.leftMargin: Margins.settingsAfterSpinEdit
                        anchors.verticalCenter: rollbackHistorySizeSpin.verticalCenter

                        text: tr.Localize("MBSuffix")
                        color: parent.enabled && context.limitRollbackHistory ? "black" : "grey"
                    }
                }

                SettingsCommon.SettingsStandardText
                {
                    text: tr.Localize("OnDetectingPossibleRollback")
                    color: parent.enabled ? "black" : "grey"
                    anchors.left: parent.left
                }

                Item
                {
                    id: isAutoMalwareActionWrapper
                    objectName: "IsAutoMalwareActionWrapper"
                    height: childrenRect.height
                    width: parent.width

                    SettingsCommon.BoolRadioGroup
                    {
                        id: isAutoMalwareAction
                        objectName: "IsAutoMalwareAction"
                        target: context
                        property: "isAutoMalwareAction"
                        trueDescription: context.interactionDisabled? tr.Localize("ActionAutoRollback") : tr.Localize("ActionAskRollback");
                        falseDescription: tr.Localize("ActionSelectRollback")
                        trueFirst: true
                        anchors.left: parent.left
                    }

                    SettingsCommon.EnumCombo
                    {
                        property Item lastRadio: isAutoMalwareAction.getRadio(2)

                        id: selectedMalwareAction
                        objectName: "SelectedMalwareAction"
                        anchors.left: parent.left
                        anchors.leftMargin: lastRadio.width
                        y: lastRadio.y - 2
                        enabled: parent.enabled && !context.isAutoMalwareAction
                        target: context
                        property: "selectedMalwareAction"
                        localizationObject: tr
                    }
                }
            }
        }
    }
}
